/***************************************************************************
 *            book-fun.c
 *
 *  Fri Sep  2 18:13:06 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomek@paradox.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <stdio.h>

#include "book-fun.h"
#include "interface.h"
#include "support.h"
#include "db-fun.h"

/*
 *	Funkcja wczytuje tytuly pojedynczych ksiazek do listy 'single_volume_tview' 
 *	z bazy danych
 */

void	s_load_books_titles	(void)	{
	GtkTreeView			*treeview;
	GtkTreeModel		*store;
	GtkTreeIter 		iter;	
	gint				status;
	gint				rows;
	gchar				*lended;
	sqlite3_stmt		*db_row;
	
	status = 0;
		
	treeview = (gpointer) glade_xml_get_widget (main_win_xml, "single_volume_tview");
	store = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
	
	g_printf(">>> Loading single volume books titles, counting books...\n");
	rows = count_returned_rows ("SELECT COUNT(id) FROM books;");
	g_printf ("<<< Books in database: %d\n", rows);
	
	sqlite3_prepare(db_handler, "SELECT id, title FROM books;", -1, &db_row, 0);	
	
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Got first book, SQLite result: %d\n", status);
	if (rows > 0)	{
		while (status == 100)		{
			gtk_list_store_append (GTK_LIST_STORE (store), &iter);
			gtk_list_store_set (GTK_LIST_STORE (store), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								-1);
			status = sqlite3_step (db_row);
		}
		g_printf ("\t<<< Got last book, SQLite result: %d\n", status);
	}
	
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja wyciaga z bazy danych informacje o ksiazce wskazanej w liscie
 *	'single_volume_book'
 */

void	s_select_book_data	(gint book_id)	{
	sqlite3_stmt	*db_row;
	gchar			sql_query[64];
	gint			status;

	g_sprintf (sql_query, "SELECT * FROM books WHERE id = %d;", book_id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	
	status = sqlite3_step (db_row);
	g_printf(">>> Selecting book data with ID = %d, SQLite result %d\n", book_id, status);
	
	book.id = sqlite3_column_int (db_row, 0);
	book.multi_volume = sqlite3_column_int (db_row, 1);
	g_sprintf (book.title, "%s", sqlite3_column_text (db_row, 2));
	book.author = sqlite3_column_int (db_row, 3);
	book.genere = sqlite3_column_int (db_row, 4);
	book.publish_house = sqlite3_column_int (db_row, 5);
	
	g_sprintf (book.isbn, "%s", sqlite3_column_text (db_row, 6));
	book.publish_year = sqlite3_column_int (db_row, 7);
	book.pages = sqlite3_column_int (db_row, 8);
	
	g_sprintf (book.description, "%s", sqlite3_column_text (db_row, 9));

	book.lended = sqlite3_column_int (db_row, 10);
	
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja zapisuje dane o ksiazce
 */

void	s_save_book (void)	{
	gchar			sql_query	[3172];
	gint			status;
	sqlite3_stmt	*db_row;
		
	g_printf (">>> Saving data base ...\n");
	
	g_sprintf (sql_query, "INSERT INTO books ("
	  				        "id, multi_volume, title, author, "
							"genere, publish_house, isbn, "
							"publish_year, pages, "
							"description, lended, tmp) "
							"VALUES ("
							"NULL, 0, \'%s\', %d, "
							"%d, %d, %s, "
							"%d, %d, \'%s\', "
							"0, 0);",
							book.title, book.author,
							book.genere, book.publish_house, book.isbn,
							book.publish_year, book.pages, book.description);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf("\t<<< Inserting new data into data base, SQLIte result: %d\n", status);
	set_statusbar_text (_("New book inserted!"));
	
	sqlite3_finalize (db_row);	
}

/*
 *	Funkcja aktualizuje dane o ksiazce
 */

void	s_update_book	(void)	{
	gchar			sql_query	[3172];
	gint			status;
	sqlite3_stmt	*db_row;
		
	g_printf (">>> Updating data base ...\n");
	
	g_sprintf (sql_query, "UPDATE books SET "
							"title=\'%s\', author=\'%d\', genere=\'%d\',"
							"publish_house=\'%d\', isbn=\'%s\', publish_year=\'%d\',"
							"pages=\'%d\', description=\'%s\' "
							"WHERE "
							"id=%d;", 
							book.title, book.author, book.genere, 
							book.publish_house, book.isbn, book.publish_year,
							book.pages,	book.description, book.id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf("\t<<< Updating data in data base, SQLIte result: %d\n", status);
	set_statusbar_text (_("Book informations updated!"));
	
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja usuwa ksiazke o wskazanym 'book_id' z tabeli 'books' w bazie danyh.
 *	Funkcja sprawdza czy pozycja nie jest wykorzystywana przez jakas pozycje 
 *	wielotomowa. Jezeli jest, wyswietlane jest ostrzezenie dla usera i ewentualnie
 *	ksiazka jest usuwana wraz z dokonaniem niezbednych modyfikacji w tabeli 
 *	'multi_volumes'
 */

void	s_remove_book					(void)	{
	gboolean		result;
	gchar			string				[1024];
	gchar			multi_volume_title	[128];
	gint			status;
	gint			multi_volume;
	sqlite3_stmt	*db_row;

	g_sprintf (string, "SELECT multi_volume FROM books WHERE id=%d;", book.id);
	sqlite3_prepare(db_handler, string, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	multi_volume = sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	if (multi_volume == 0)	{
		g_sprintf (string, "DELETE FROM books WHERE id=%d;", book.id);
		sqlite3_prepare(db_handler, string, -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf(">>> Deleting selected book data from database, SQLite result: %d\n", status);
		set_statusbar_text (_("Book removed from data base."));
		sqlite3_finalize (db_row);
	}
	else	{
		g_sprintf (string, "SELECT title FROM multi_volumes WHERE id=%d;", multi_volume);
		sqlite3_prepare(db_handler, string, -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_sprintf (string, _("Book you're renoving at the moment is a part of multi volume book: "
						   "\"%s\". If you remove this book from this database it will be removed "
						   "from above multi volume book too.\n\nDo you want to continue?"), sqlite3_column_text (db_row, 0));
		sqlite3_finalize (db_row);
		
		result = show_question_dlg (_("Problem while removing book"), string);
		if (result == TRUE)	{
			g_sprintf (string, "DELETE FROM books WHERE id=%d;", book.id);
			sqlite3_prepare(db_handler, string, -1, &db_row, 0);
			status = sqlite3_step (db_row);
			sqlite3_finalize (db_row);
			g_printf(">>> Deleting selected book data from database, SQLite result: %d\n", status);
			
			g_sprintf (string, "UPDATE multi_volumes SET volume_num = volume_num -1 WHERE id=%d;", multi_volume);
			sqlite3_prepare(db_handler, string, -1, &db_row, 0);
			status = sqlite3_step (db_row);
			sqlite3_finalize (db_row);
			g_printf(">>> Updating table \'multi_volumes\', SQLite result: %d\n", status);
			
			set_statusbar_text (_("Book removed from data base."));	
		}
	}
}

/*
 *	Funkcja wczytuje dane wskazanej ksiazki do pol w 'main_win' i tworzy modele
 *	dla wszystkich widgetow 'GtkComboBox' wybierajha przy tym opce zapisana w 
 *	bazie danych
 */

void	s_display_book_data	(void)	{
	GtkWidget		*tmp;
	GtkTextBuffer 	*text_buffer;
	gchar			sql_query	[128];
	sqlite3_stmt	*db_row;
	
	tmp = glade_xml_get_widget (main_win_xml, "s_title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), book.title);

	tmp = glade_xml_get_widget (main_win_xml, "s_author_lb");
	g_sprintf (sql_query, "SELECT author FROM authors WHERE id=\'%d\';", book.author);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (main_win_xml, "s_genere_lb");
	g_sprintf (sql_query, "SELECT genere FROM generes WHERE id=\'%d\';", book.genere);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (main_win_xml, "s_pub_house_lb");
	g_sprintf (sql_query, "SELECT publish_house FROM publish_houses WHERE id=\'%d\';", 
							book.publish_house);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (main_win_xml, "s_isbn_lb");
	gtk_label_set_text (GTK_LABEL (tmp), book.isbn);
	
	tmp = glade_xml_get_widget (main_win_xml, "s_pub_year_lb");
	g_sprintf (sql_query, "%d", book.publish_year);
	gtk_label_set_text (GTK_LABEL (tmp), sql_query);
	
	tmp = glade_xml_get_widget (main_win_xml, "s_page_number_lb");
	g_sprintf (sql_query, "%d", book.pages);
	gtk_label_set_text (GTK_LABEL (tmp), sql_query);
	/*
	if (book.lended == 0)	{
		tmp = glade_xml_get_widget (main_xml, "s_lend_book_togbut");
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp), FALSE);
	}
	else	{
		tmp = glade_xml_get_widget (main_xml, "s_lend_book_togbut");
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp), TRUE);
	}
	*/
	tmp = glade_xml_get_widget (main_win_xml, "s_description_tview");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, book.description, strlen (book.description));
	
	set_widget_sensinitive (main_win_xml, "s_remove_book_but", TRUE);
	set_widget_sensinitive (main_win_xml, "s_edit_book_but", TRUE);
}

/*
 *	Funkcja czysci pola w oknie 'main_win'
 */

void	s_clear_book_display (void)	{
	GtkWidget		*tmp;
	GtkTextBuffer 	*text_buffer;
	
	tmp = glade_xml_get_widget (main_win_xml, "s_title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");

	tmp = glade_xml_get_widget (main_win_xml, "s_author_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "s_genere_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "s_pub_house_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "s_isbn_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "s_pub_year_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "s_page_number_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "s_description_tview");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, "", strlen (""));
	
	set_widget_sensinitive (main_win_xml, "s_remove_book_but", FALSE);
	set_widget_sensinitive (main_win_xml, "s_edit_book_but", FALSE);
}

/*
 *	Funkcja laduje modele z tabel 'authors', 'generes' i 'publish_houses' do 
 *	odpowiednich widgetow 'GtkEntry' okna 'single_book_dlg'
 */

void	s_load_book_dlg_data			(void)	{
	GtkListStore		*list;
	GtkTreeIter			iter;
	GtkEntryCompletion	*completion;
	GtkWidget			*tmp;
	gint				status;
	gint				rows;
	sqlite3_stmt		*db_row;
	
	g_printf (">>> Loading base data into 'single_book_dlg'...\n");
	
	/*=====   GtkEntry 's_author_en'   =====*/
	tmp = glade_xml_get_widget (single_book_xml, "s_author_en");
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = 1;/*count_returned_rows ("SELECT COUNT(id) FROM authors;");*/
	if (rows > 0)	{
		sqlite3_prepare(db_handler, "SELECT author FROM authors;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading first row table \'authors\', SQLite result: %d\n", status);
	
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
			g_printf ("\t<<< Loading last row table \'authors\', SQLite result: %d\n", status);
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));
		gtk_combo_box_set_model (GTK_COMBO_BOX (tmp), GTK_TREE_MODEL (list));	
		
		tmp = (gpointer) GTK_ENTRY (GTK_BIN (tmp)->child);		
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		g_object_unref (G_OBJECT (completion)); 
	}
	
	/*=====   GtkEntry 's_genere_en'   =====*/
	tmp = glade_xml_get_widget (single_book_xml, "s_genere_en");
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM generes;");
	if (rows > 0)	{
		sqlite3_prepare(db_handler, "SELECT genere FROM generes;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading first row table \'authors\', SQLite result: %d\n", status);
	
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
			g_printf ("\t<<< Loading last row table \'authors\', SQLite result: %d\n", status);
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));
		gtk_combo_box_set_model (GTK_COMBO_BOX (tmp), GTK_TREE_MODEL (list));	
		
		tmp = (gpointer) GTK_ENTRY (GTK_BIN (tmp)->child);		
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		g_object_unref (G_OBJECT (completion)); 
	}
	
	/*=====   GtkEntry 's_pub_house_en'   =====*/
	tmp = glade_xml_get_widget (single_book_xml, "s_pub_house_en");
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM publish_houses;");
	if (rows > 0)	{
		sqlite3_prepare(db_handler, "SELECT publish_house FROM publish_houses;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading first row table \'publish_houses\', SQLite result: %d\n", status);
	
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
			g_printf ("\t<<< Loading last row table \'publish_houses\', SQLite result: %d\n", status);
		}
		
		sqlite3_finalize (db_row);
		
		gtk_combo_box_set_model (GTK_COMBO_BOX (tmp), GTK_TREE_MODEL (list));
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		
		tmp = (gpointer) GTK_ENTRY (GTK_BIN (tmp)->child);		
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		g_object_unref (G_OBJECT (completion)); 
	}
}

/*
 *	Funkcja wczytuje dane wskazanej ksiazki do okna edycji. 
 */

void			s_edit_book_data				(void)	{
	GtkWidget			*tmp;
	GtkTextBuffer		*text_buffer;
	sqlite3_stmt		*db_row;
	gchar				sql_query[64];
	
	tmp = glade_xml_get_widget (single_book_xml, "s_title_en");
	gtk_entry_set_text (GTK_ENTRY (tmp), book.title);

	tmp = glade_xml_get_widget (single_book_xml, "s_author_en");
	g_sprintf (sql_query, "SELECT author FROM authors WHERE id=\'%d\';", book.author);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (tmp)->child), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_genere_en");
	g_sprintf (sql_query, "SELECT genere FROM generes WHERE id=\'%d\';", book.genere);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (tmp)->child), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_pub_house_en");
	g_sprintf (sql_query, "SELECT publish_house FROM publish_houses WHERE id=\'%d\';", book.publish_house);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (tmp)->child), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_isbn_en");
	gtk_entry_set_text (GTK_ENTRY (tmp), book.isbn);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_pub_year_en");
	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tmp), book.publish_year);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_pages_en");
	gtk_spin_button_set_value (GTK_SPIN_BUTTON (tmp), book.pages);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_desc_en");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, book.description, strlen (book.description));
}

/*
 *	Funkcja sprawdza poprawnosc wprowadzanych danych, jezeli dane sa ok
 *	zapis danych jest kontynuowany, jezeli dane sa bledne wyswietlamy
 *	komunikat o bledach.
 *	Przy widgetach 'author_en', 'genere_en' i 'pub_house_en' wystepuje
 *	mozliwosc dodania ich zawartosci do bazy danych
 *	
 *	Funkcja sprawdza dane bardzo skrupulatnie!
 */

gboolean	s_check_book_data		(void)	{
	GtkWidget		*tmp;
	GtkTextBuffer 	*text_buffer;
	GtkTextIter		text_start;	
	GtkTextIter		text_end;
	sqlite3_stmt	*db_row;
	gchar			string			[128];
	gchar			isbn			[16];
	gboolean		result;
	gint			i;
	
	i = 1;
	
	tmp = glade_xml_get_widget (single_book_xml, "s_title_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Title\' can't be empty!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (single_book_xml, "s_author_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Author\' can't be empty!"), 1);
		return FALSE;
	}
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) > 30)	{
		show_message_dlg (_("Wrong data"), _("Value in field \'Author\' can't be longer, than 30 characters!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (single_book_xml, "s_genere_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Genere\' can't be empty!"), 1);
		return FALSE;
	}
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) > 30)	{
		show_message_dlg (_("Wrong data"), _("Value in field \'Genere\' can't be longer, than 30 characters!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (single_book_xml, "s_pub_house_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Publish house\' can't be empty!"), 1);
		return FALSE;
	}
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) > 30)	{
		show_message_dlg (_("Wrong data"), _("Value in field \'Publish house\' can't be longer, than 30 characters!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (single_book_xml, "s_isbn_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'ISBN\' can't be empty!"), 1);
		return FALSE;
	}
	
	if(!g_utf8_validate (gtk_entry_get_text (GTK_ENTRY (tmp)), -1, NULL))	{
		show_message_dlg (_("Invalid field value"),
						  _("Field \'ISBN\' contain wrong UTF-8 value!"), 1);
		FALSE;
	}
	
	g_sprintf (isbn, "%s", gtk_entry_get_text (GTK_ENTRY (tmp)));
	if ( !g_unichar_isdigit (g_utf8_get_char (isbn)))	{
		show_message_dlg (_("Invalid field value"),
						  _("Field \'ISBN\' can't contain other value\n"
							"than numeric signs!"), 1);
		return FALSE;
	}
	while (i < strlen (gtk_entry_get_text (GTK_ENTRY (tmp))))	{
		if ( !g_unichar_isdigit ((isbn [i])))	{
			show_message_dlg (_("Invalid field value"),
							  _("Field \'ISBN\' can't contain other value\n"
								"than numeric signs!"), 1);
			return FALSE;
		}
		++i;
	}
	
	tmp = glade_xml_get_widget (single_book_xml, "s_desc_en");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_get_bounds (text_buffer, &text_start, &text_end);
	if (strlen (gtk_text_buffer_get_text (text_buffer, &text_start, &text_end, TRUE)) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Description\' can't be empty!"), 1);
		return FALSE;
	}	
	else if (strlen (gtk_text_buffer_get_text (text_buffer, &text_start, &text_end, TRUE)) > 2000)	{
		show_message_dlg (_("Wrong data"), _("Description can't be longer than 2000 signs!"), 1);
		return FALSE;
	}
	
	/*	Sprawdzamy czy zawartosc 'author_en', 'genere_en', 'pub_house_en' jest
	 *	juz w bazie danych, jezeli nir to pytamy usera czy chce ja teraz dodac */
	
	tmp = glade_xml_get_widget (single_book_xml, "s_author_en");
	g_sprintf (string, "SELECT COUNT(id) FROM authors WHERE author=\'%s\';", 
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	
	if (count_returned_rows (string) == 0)	{
		g_sprintf (string, _("There is no author named \"%s\" in database, "
							 "do you want to add her/him now?"),
							 gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
		result = show_question_dlg (_("New author"), string);
		if (result == TRUE)	{
			add_item_to_database (GTK_WIDGET (GTK_BIN (tmp)->child), 0);
		}
		else	{
			return FALSE;
		}
	}
	
	tmp = glade_xml_get_widget (single_book_xml, "s_genere_en");
	g_sprintf (string, "SELECT COUNT(id) FROM generes WHERE genere=\'%s\';",
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	
	if (count_returned_rows (string) == 0)	{
		g_sprintf (string, _("There is no genre \"%s\" in database, "
							 "do you want to add it now?"),
							 gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));

		result = show_question_dlg (_("New genere"), string);
		if (result == TRUE)	{
			add_item_to_database (GTK_WIDGET (GTK_BIN (tmp)->child), 1);
		}
		else	{
			return FALSE;
		}
	}
	
	tmp = glade_xml_get_widget (single_book_xml, "s_pub_house_en");
	g_sprintf (string, "SELECT COUNT(id) FROM publish_houses WHERE publish_house=\'%s\';",
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	
	if (count_returned_rows (string) == 0)	{
		g_sprintf (string, _("There is no publish house \"%s\" in database, "
							 "do you want to add it now?"),
							 gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
					
		result = show_question_dlg (_("New pubish house"), string);
		if (result == TRUE)	{
			add_item_to_database (GTK_WIDGET (GTK_BIN (tmp)->child), 2);
		}
		else	{
			return FALSE;
		}
	}
	return TRUE;
}

/*
 *	Funkcja wyciaga dane o ksiazkach z okna 'single_book_dlg' i uaktualnia
 *	strukture 'book'. 
 */

void	s_update_book_data	(void)	{
	GtkWidget		*tmp;
	GtkTextBuffer 	*text_buffer;
	GtkTextIter		text_start;	
	GtkTextIter		text_end;
	sqlite3_stmt	*db_row;
	gchar			sql_query[128];
	
	tmp = glade_xml_get_widget (single_book_xml, "s_title_en");
	g_sprintf (book.title, "%s", gtk_entry_get_text (GTK_ENTRY (tmp)));

	tmp = glade_xml_get_widget (single_book_xml, "s_author_en");
	g_sprintf (sql_query, "SELECT id FROM authors WHERE author=\'%s\';", 
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	sqlite3_prepare (db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	book.author =  sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_genere_en");
	g_sprintf (sql_query, "SELECT id FROM generes WHERE genere=\'%s\';", 
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	sqlite3_prepare (db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	book.genere =  sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_pub_house_en");
	g_sprintf (sql_query, "SELECT id FROM publish_houses WHERE publish_house=\'%s\';", 
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	sqlite3_prepare (db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	book.publish_house =  sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (single_book_xml, "s_isbn_en");
	g_sprintf (book.isbn, "%s", gtk_entry_get_text (GTK_ENTRY (tmp)));
	
	tmp = glade_xml_get_widget (single_book_xml, "s_pub_year_en");
	book.publish_year = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON (tmp));
	
	tmp = glade_xml_get_widget (single_book_xml, "s_pages_en");
	book.pages = (gint) gtk_spin_button_get_value (GTK_SPIN_BUTTON (tmp));

	tmp = glade_xml_get_widget (single_book_xml, "s_desc_en");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_get_bounds (text_buffer, &text_start, &text_end);
	g_sprintf (book.description, "%s", gtk_text_buffer_get_text (text_buffer, &text_start, &text_end, TRUE));
}

void	s_reset_book_stuc			(void)	{
	book.id = 0;
	g_sprintf (book.title, "");
	book.author = 0;
	book.genere = 0;
	book.publish_house = 0;
	g_sprintf (book.isbn, "");
	book.publish_year = 0;
	book.pages = 0;
	g_sprintf (book.description, "");
	book.lended = 0;
}

/*
 *	Funkcja pobiera i wyswietla w oknie 'display_book_info_dlg' dane o ksiazce
 *	o 'id' wskazanym w argumencie. Funkcja jest niezalezna - nie korzysta z
 *	struktury 'books' zadeklarowanej w pliku 'book-fun.h'
 */

void	s_show_book_info		(gint	id)	{
	GtkTextBuffer 	*text_buffer;
	GtkWidget		*tmp;
	sqlite3_stmt	*db_row;
	gchar			sql_query	[512];
	gint			status;
	gint			author_id;
	gint			genere_id;
	gint			publish_house_id;
	
	g_sprintf (sql_query, "SELECT title, author, genere, publish_house, "
						  "isbn, publish_year, pages, description "
						  "FROM books WHERE id=%d;", id);
	
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	
	g_printf (">>> Selecting book data, SQLite result: %d\n", status);
	
	tmp = glade_xml_get_widget (display_book_info_xml, "s_title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	
	author_id = sqlite3_column_int (db_row, 1);
	genere_id = sqlite3_column_int (db_row, 2);
	publish_house_id = sqlite3_column_int (db_row, 3);

	tmp = glade_xml_get_widget (display_book_info_xml, "s_isbn_lb");
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 4));
	
	tmp = glade_xml_get_widget (display_book_info_xml, "s_pages_lb");
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 5));
	
	tmp = glade_xml_get_widget (display_book_info_xml, "s_pub_year_lb");
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 6));
	
	tmp = glade_xml_get_widget (display_book_info_xml, "s_description_tview");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, (gchar *) sqlite3_column_text (db_row, 7), strlen (sqlite3_column_text (db_row, 7)));
	
	sqlite3_finalize (db_row);
	
	/*	Ladujemy jesze pola: autor, gatunek, wydawnictwo	*/
	
	g_sprintf (sql_query, "SELECT author FROM authors WHERE id=%d;", author_id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	tmp = glade_xml_get_widget (display_book_info_xml, "s_author_lb");
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	g_sprintf (sql_query, "SELECT genere FROM generes WHERE id=%d;", genere_id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	tmp = glade_xml_get_widget (display_book_info_xml, "s_genere_lb");
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	g_sprintf (sql_query, "SELECT publish_house FROM publish_houses WHERE id=%d;", publish_house_id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	tmp = glade_xml_get_widget (display_book_info_xml, "s_pub_house_lb");
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
}

/********************************************************************
 ********************************************************************
 **                                                                **
 **			Funkcje obslugi ksiazek wielotomowych				   **
 **																   **
 ********************************************************************
 ********************************************************************/


/*
 *	Funkcja wczytuje tytuly wielo tomowych ksiazek do listy 'multi_volume_tview' 
 *	z bazy danych
 */

void	m_load_books_titles	(void)	{
	GtkTreeView			*treeview;
	GtkTreeModel		*store;
	GtkTreeIter 		iter;	
	gint				status;
	gint				rows;
	gint				s_books [30];
	gchar				*lended;
	gchar				sql_query	[64];	
	sqlite3_stmt		*db_row;
	
	status = 100;

	treeview = (gpointer) glade_xml_get_widget (main_win_xml, "multi_volume_tview");
	store = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
	
	g_printf(">>> Loading multi volume books titles, counting books...\n");
	rows = count_returned_rows ("SELECT COUNT(id) FROM multi_volumes;");
	g_printf ("<<< Multi volume books in database: %d\n", rows);
	
	sqlite3_prepare(db_handler, "SELECT id, title FROM multi_volumes;", -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	
	g_printf ("\t<<< Got first book, SQLite result: %d\n", status);
	if (rows > 0)	{
		while (status == 100)		{
			gtk_list_store_append (GTK_LIST_STORE (store), &iter);
			gtk_list_store_set (GTK_LIST_STORE (store), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								-1);
			
			status = sqlite3_step (db_row);
		}
		g_printf ("\t<<< Got last book, SQLite result: %d\n", status);
	}
	
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja wyciaga z bazy danych informacje o ksiazce wskazanej w liscie
 *	'multi_volume_book'
 */

void	m_select_book_data	(gint book_id)	{
	sqlite3_stmt	*db_row;
	gchar			sql_query[64];
	gint			status;

	g_sprintf (sql_query, "SELECT * FROM multi_volumes WHERE id = %d;", book_id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	
	status = sqlite3_step (db_row);
	g_printf(">>> Selecting book data with ID = %d, SQLite result %d\n", book_id, status);
	
	multi_volume.id = sqlite3_column_int (db_row, 0);
	g_sprintf (multi_volume.title, "%s", sqlite3_column_text (db_row, 1));
	multi_volume.author = sqlite3_column_int (db_row, 2);
	multi_volume.genere = sqlite3_column_int (db_row, 3);
	multi_volume.publish_house = sqlite3_column_int (db_row, 4);
	
	multi_volume.volume_num = sqlite3_column_int (db_row, 5);
	
	g_sprintf (multi_volume.description, "%s", sqlite3_column_text (db_row, 6));

	multi_volume.lended = sqlite3_column_int (db_row, 7);
	
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja laduje ksiazki z tabeli 'books' ktorych pole 'multi_volume' ma
 *	wartosc 0 do listy 'm_books_tview' w oknie 'select_m_books_dlg'
 *
 *	Wyjatkiem jest systuacja, gdy edytujemy ksiazke wielotomowa. Wtedy i tylko
 *	wtedy glownym argumentem wyboru jest wartosc pola 'tmp' w tabeli 'books',
 *	a iue wartosc pola 'multi_volume'
 *
 *	FIXME
 */

void	m_load_single_books_titles	(void)	{
	GtkTreeView			*treeview;
	GtkTreeModel		*store;
	GtkTreeIter 		iter;	
	gint				status;
	gint				rows;
	sqlite3_stmt		*db_row;
	gchar				sql_query	[128];
	
	status = 0;
		
	treeview = (gpointer) glade_xml_get_widget (select_m_books_xml, "single_books_tview");
	store = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
	
	g_printf(">>> Loading first group books titles, counting books...\n");
	rows = count_returned_rows ("SELECT COUNT(id) FROM books WHERE multi_volume=0  AND tmp=0;");
	g_printf ("<<< Books in database: %d\n", rows);
	
	sqlite3_prepare(db_handler, "SELECT id, title FROM books WHERE multi_volume=0  AND tmp=0;", -1, &db_row, 0);	
	
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Got first book, SQLite result: %d\n", status);
	if (rows > 0)	{
		while (status == 100)		{
			gtk_list_store_append (GTK_LIST_STORE (store), &iter);
			gtk_list_store_set (GTK_LIST_STORE (store), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								-1);
			status = sqlite3_step (db_row);
		}
		g_printf ("\t<<< Got last book, SQLite result: %d\n", status);
	}
	
	sqlite3_finalize (db_row);
	printf ("%d\n\n", multi_volume.id);
	if (multi_volume.id > 0)	{	
		g_printf(">>> Loading second group books titles, counting books...\n");
		g_sprintf (sql_query, "SELECT COUNT(id) FROM books WHERE multi_volume=%d  AND tmp=0;", multi_volume.id);
		rows = count_returned_rows (sql_query);
		g_printf ("<<< Books in database: %d\n", rows);
	
		g_sprintf (sql_query, "SELECT id, title FROM books WHERE multi_volume=%d  AND tmp=0;", multi_volume.id);
		sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Got first book, SQLite result: %d\n", status);
		if (rows > 0)	{
			while (status == 100)		{
				gtk_list_store_append (GTK_LIST_STORE (store), &iter);
				gtk_list_store_set (GTK_LIST_STORE (store), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								-1);
				status = sqlite3_step (db_row);
			}
			g_printf ("\t<<< Got last book, SQLite result: %d\n", status);
		}
	
		sqlite3_finalize (db_row);
	}
}

void	m_add_book_to_books_tview			(void)	{
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*treeview;
	gint				book_id;
	gint				status;
	gchar				string	[1024];
	sqlite3_stmt		*db_row;
	
	treeview = glade_xml_get_widget (select_m_books_xml, "single_books_tview");
	
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	gtk_tree_selection_get_selected(selection, &model, &iter);
	
	gtk_tree_model_get (model, &iter, 0, &book_id, -1);
	
	treeview = glade_xml_get_widget (multi_volume_xml, "m_books_tview");
	model = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
	
	g_printf (">>> Setting books for multi volume item...\n");
	
	g_sprintf (string, "SELECT id, title FROM books WHERE id=%d;", book_id);
	sqlite3_prepare(db_handler, string, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Selecting some book informations from database, SQLite result: %d\n", status);
	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
	gtk_list_store_set (GTK_LIST_STORE (model), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								-1);
	sqlite3_finalize (db_row);
	
	g_sprintf (string, "UPDATE books SET tmp=1 WHERE id=%d", book_id);
	sqlite3_prepare(db_handler, string, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Setting value in \'tmp\' field for book with id=%d, SQLite result: %d\n", 
				book_id, status);				
	sqlite3_finalize (db_row);
}

void	m_remove_book_from_m_books_tview	(void)	{
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*treeview;
	gint				book_id;
	gint				status;
	gchar				string	[1024];
	sqlite3_stmt		*db_row;
	
	treeview = glade_xml_get_widget (multi_volume_xml, "m_books_tview");
	
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	gtk_tree_selection_get_selected(selection, &model, &iter);
	
	gtk_tree_model_get (model, &iter, 0, &book_id, -1);
	
	gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
	
	g_printf (">>> Remove book from multi volume item...\n");
	g_sprintf (string, "UPDATE books SET tmp=0 WHERE id=%d", book_id);
	sqlite3_prepare(db_handler, string, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Setting value in \'tmp\' field for book with id=%d, SQLite result: %d\n", 
				book_id, status);				
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja laduje modele z tabel 'authors', 'generes' i 'publish_houses' do 
 *	odpowiednich widgetow 'GtkEntry' okna 'multi_volume_dlg'
 */

void	m_load_book_dlg_data		(void)	{
	GtkListStore		*list;
	GtkTreeIter			iter;
	GtkEntryCompletion	*completion;
	GtkWidget			*tmp;
	gint				status;
	gint				rows;
	sqlite3_stmt		*db_row;
	
	g_printf (">>> Loading base data into 'multi_volume_dlg'...\n");
	
	/*=====   GtkEntry 'm_author_en'   =====*/
	tmp = glade_xml_get_widget (multi_volume_xml, "m_author_en");
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = 1;/*count_returned_rows ("SELECT COUNT(id) FROM authors;");*/
	if (rows > 0)	{
		sqlite3_prepare(db_handler, "SELECT author FROM authors;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading first row table \'authors\', SQLite result: %d\n", status);
	
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
			g_printf ("\t<<< Loading last row table \'authors\', SQLite result: %d\n", status);
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));
		gtk_combo_box_set_model (GTK_COMBO_BOX (tmp), GTK_TREE_MODEL (list));	
		
		tmp = (gpointer) GTK_ENTRY (GTK_BIN (tmp)->child);		
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		g_object_unref (G_OBJECT (completion)); 
	}
	
	/*=====   GtkEntry 'm_genere_en'   =====*/
	tmp = glade_xml_get_widget (multi_volume_xml, "m_genere_en");
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM generes;");
	if (rows > 0)	{
		sqlite3_prepare(db_handler, "SELECT genere FROM generes;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading first row table \'authors\', SQLite result: %d\n", status);
	
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
			g_printf ("\t<<< Loading last row table \'authors\', SQLite result: %d\n", status);
		}
		
		sqlite3_finalize (db_row);
		
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));
		gtk_combo_box_set_model (GTK_COMBO_BOX (tmp), GTK_TREE_MODEL (list));	
		
		tmp = (gpointer) GTK_ENTRY (GTK_BIN (tmp)->child);		
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		g_object_unref (G_OBJECT (completion)); 
	}
	
	/*=====   GtkEntry 'm_pub_house_en'   =====*/
	tmp = glade_xml_get_widget (multi_volume_xml, "m_pub_house_en");
	completion = gtk_entry_completion_new ();
	gtk_entry_completion_set_inline_completion (completion, TRUE);
	gtk_entry_completion_set_text_column (completion, 0);
	
	rows = count_returned_rows ("SELECT COUNT(id) FROM publish_houses;");
	if (rows > 0)	{
		sqlite3_prepare(db_handler, "SELECT publish_house FROM publish_houses;", -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf ("\t<<< Loading first row table \'publish_houses\', SQLite result: %d\n", status);
	
		list = gtk_list_store_new (1, G_TYPE_STRING);
		if (status == 101)	{
			gtk_list_store_append (list, &iter);
			gtk_list_store_set (list, &iter,
								0, sqlite3_column_text (db_row, 0),
								-1);
		}
		else	{
			while (status == 100)	{
				gtk_list_store_append (list, &iter);
				gtk_list_store_set (list, &iter,
									0, sqlite3_column_text (db_row, 0),
									-1);
				status = sqlite3_step (db_row);
			}
			g_printf ("\t<<< Loading last row table \'publish_houses\', SQLite result: %d\n", status);
		}
		
		sqlite3_finalize (db_row);
		
		gtk_combo_box_set_model (GTK_COMBO_BOX (tmp), GTK_TREE_MODEL (list));
		gtk_entry_completion_set_model (completion, GTK_TREE_MODEL (list));	
		
		tmp = (gpointer) GTK_ENTRY (GTK_BIN (tmp)->child);		
		gtk_entry_set_completion (GTK_ENTRY (tmp), completion);
		
		g_object_unref (G_OBJECT (completion)); 
	}
}

/*
 *	Funkcja oblicza aktualna liczbe ksiazek znajdujacych sie na liscie. 
 *	Jezeli liczba ksiazek osignie 30 (to maks. liczba ksiazek) przycisk 
 *	'm_add_book_but' zostaje zablokowane.
 *
 *	'm_books_twiev' w oknie 'multi_volume_dlg'
 *		mode = 0 - odejmujey jedna ksiazke z listy
 *		mode = 1 - dodajemy jedna ksiazke
 */

void	m_count_books_in_list	(gint	mode) {
	GtkWidget	*widget;
	gint 		number;
	gchar		string [2];
	
	widget = glade_xml_get_widget (multi_volume_xml, "m_books_number_lb");
	sscanf (gtk_label_get_text (GTK_LABEL (widget)), "%d", &number);
	
	switch (mode)	{
		case 0:
			--number;
			g_sprintf (string, "%d", number);
			gtk_label_set_text (GTK_LABEL (widget), string);
			break;
		case 1:
			++number;
			g_sprintf (string, "%d", number);
			gtk_label_set_text (GTK_LABEL (widget), string);
			break;
	}
	
	if (number == 30)	{
		set_widget_sensinitive (multi_volume_xml, "m_add_book_but", FALSE);
		set_widget_sensinitive (multi_volume_xml, "m_remove_book_but", FALSE);
	}
	else	{
		set_widget_sensinitive (multi_volume_xml, "m_add_book_but", TRUE);
		set_widget_sensinitive (multi_volume_xml, "m_remove_book_but", FALSE);
	}
}

/*
 *	Funkcja sprawdza poprawnosc wprowadzanych danych, jezeli dane sa ok
 *	zapis danych jest kontynuowany, jezeli dane sa bledne wyswietlamy
 *	komunikat o bledach.
 *	Przy widgetach 'author_en', 'genere_en' i 'pub_house_en' wystepuje
 *	mozliwosc dodania ich zawartosci do bazy danych
 *	
 *	Funkcja sprawdza dane bardzo skrupulatnie!
 */

gboolean	m_check_book_data		(void)	{
	GtkWidget		*tmp;
	GtkTextBuffer 	*text_buffer;
	GtkTextIter		text_start;	
	GtkTextIter		text_end;
	sqlite3_stmt	*db_row;
	gchar			string			[128];
	gchar			isbn;
	gint			number;
	gboolean		result;
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_title_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (tmp))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Title\' can't be empty!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_author_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Author\' can't be empty!"), 1);
		return FALSE;
	}
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) > 30)	{
		show_message_dlg (_("Wrong data"), _("Value in field \'Author\' can't be longer, than 30 characters!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_genere_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Genere\' can't be empty!"), 1);
		return FALSE;
	}
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) > 30)	{
		show_message_dlg (_("Wrong data"), _("Value in field \'Genere\' can't be longer, than 30 characters!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_pub_house_en");
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Publish house\' can't be empty!"), 1);
		return FALSE;
	}
	if (strlen (gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child))) > 30)	{
		show_message_dlg (_("Wrong data"), _("Value in field \'Publish house\' can't be longer, than 30 characters!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_description_en");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_get_bounds (text_buffer, &text_start, &text_end);
	if (strlen (gtk_text_buffer_get_text (text_buffer, &text_start, &text_end, TRUE)) == 0)	{
		show_message_dlg (_("Wrong data"), _("Field \'Description\' can't be empty!"), 1);
		return FALSE;
	}
	else if (strlen (gtk_text_buffer_get_text (text_buffer, &text_start, &text_end, TRUE)) > 2000)	{
		show_message_dlg (_("Wrong data"), _("Description can't be longer than 2000 signs!"), 1);
		return FALSE;
	}
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_books_number_lb");
	sscanf (gtk_label_get_text (GTK_LABEL (tmp)), "%d", &number);
	if (number == 0 || number == 1 || number < 0)	{
		show_message_dlg (_("Wrong data"), _("Multi volume book can contain minimum two "
						"single book!"), 1);
		return FALSE;
	}
	
	/*	Sprawdzamy czy zawartosc 'author_en', 'genere_en', 'pub_house_en' jest
	 *	juz w bazie danych, jezeli nir to pytamy usera czy chce ja teraz dodac */
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_author_en");
	g_sprintf (string, "SELECT COUNT(id) FROM authors WHERE author=\'%s\';", 
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	
	if (count_returned_rows (string) == 0)	{
		g_sprintf (string, _("There is no author named \"%s\" in database, "
							 "do you want to add her/him now?"),
							 gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
		result = show_question_dlg (_("New author"), string);
		if (result == TRUE)	{
			add_item_to_database (GTK_WIDGET (GTK_BIN (tmp)->child), 0);
		}
		else	{
			return FALSE;
		}
	}
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_genere_en");
	g_sprintf (string, "SELECT COUNT(id) FROM generes WHERE genere=\'%s\';",
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	
	if (count_returned_rows (string) == 0)	{
		g_sprintf (string, _("There is no genre \"%s\" in database, "
							 "do you want to add it now?"),
							 gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));

		result = show_question_dlg (_("New genere"), string);
		if (result == TRUE)	{
			add_item_to_database (GTK_WIDGET (GTK_BIN (tmp)->child), 1);
		}
		else	{
			return FALSE;
		}
	}
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_pub_house_en");
	g_sprintf (string, "SELECT COUNT(id) FROM publish_houses WHERE publish_house=\'%s\';",
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	
	if (count_returned_rows (string) == 0)	{
		g_sprintf (string, _("There is no publish house \"%s\" in database, "
							 "do you want to add it now?"),
							 gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
					
		result = show_question_dlg (_("New pubish house"), string);
		if (result == TRUE)	{
			add_item_to_database (GTK_WIDGET (GTK_BIN (tmp)->child), 2);
		}
		else	{
			return FALSE;
		}
	}
	return TRUE;
}

/*
 *	Funkcja wyciaga dane o ksiazkach z okna 'multi_volume_dlg' i uaktualnia
 *	strukture 'multi_volume'. 
 *	Funkcja wybiera numery ID ksiazek z listy 'm_books_tview' w oknie 
 *	'multi_volume_dlg'
 */

void	m_update_book_data	(void)	{
	GtkTreeModel	*store;
	GtkTreeIter 	iter;
	gboolean		status;
	GtkWidget		*tmp;
	GtkTextBuffer 	*text_buffer;
	GtkTextIter		text_start;	
	GtkTextIter		text_end;
	sqlite3_stmt	*db_row;
	gchar			sql_query[128];
	gint			i;
	gint			ddd;
	
	i = 0;
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_title_en");
	g_sprintf (multi_volume.title, "%s", gtk_entry_get_text (GTK_ENTRY (tmp)));

	tmp = glade_xml_get_widget (multi_volume_xml, "m_author_en");
	g_sprintf (sql_query, "SELECT id FROM authors WHERE author=\'%s\';", 
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	sqlite3_prepare (db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	multi_volume.author =  sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_genere_en");
	g_sprintf (sql_query, "SELECT id FROM generes WHERE genere=\'%s\';", 
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	sqlite3_prepare (db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	multi_volume.genere =  sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_pub_house_en");
	g_sprintf (sql_query, "SELECT id FROM publish_houses WHERE publish_house=\'%s\';", 
						  gtk_entry_get_text (GTK_ENTRY (GTK_BIN (tmp)->child)));
	sqlite3_prepare (db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	multi_volume.publish_house =  sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);

	tmp = glade_xml_get_widget (multi_volume_xml, "m_description_en");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_get_bounds (text_buffer, &text_start, &text_end);
	g_sprintf (multi_volume.description, "%s", gtk_text_buffer_get_text (text_buffer, &text_start, &text_end, TRUE));
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_books_number_lb");
	sscanf (gtk_label_get_text (GTK_LABEL (tmp)), "%d", &multi_volume.volume_num);
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_books_tview");
	store = gtk_tree_view_get_model (GTK_TREE_VIEW (tmp));

	gtk_tree_model_get_iter_first (store, &iter);
	gtk_tree_model_get (store, &iter, 0, &multi_volume.books_ids [i], -1);		
	++i;
	status = gtk_tree_model_iter_next (store, &iter);
	
	while (status == TRUE)	{
		gtk_tree_model_get (store, &iter, 0, &multi_volume.books_ids [i], -1);
		status = gtk_tree_model_iter_next (store, &iter);
		++i;
	}
}

/*
 *	Funkcja zapisuje nowa ksiazke wielotomowa w bazie danych. Fubkcja konweruje
 *	zmienna 'books_ids' struktury 'multi_volume' na ciag znakow.
 */

void			m_save_book				(void)	{
	gchar			sql_query	[3172];
	gint			status;
	gint			i;
	gint			id;
	gint			real_voleme_num;
	sqlite3_stmt	*db_row;
	
	i = 0;
	real_voleme_num = multi_volume.volume_num;
	g_sprintf (sql_query, "INSERT INTO multi_volumes ("
						"id, title, "
						"author, genere, publish_house, "
						"volume_num, description, lended) "
						"VALUES ("
						"NULL, \'%s\', "
						"%d, %d, %d, "
						"%d, \'%s\', 0);",
						multi_volume.title,
						multi_volume.author, multi_volume.genere, multi_volume.publish_house, 
						multi_volume.volume_num, multi_volume.description);
	
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf("\t<<< Inserting new data into data base, SQLIte result: %d\n", status);
	sqlite3_finalize (db_row);
		
	sqlite3_prepare(db_handler, "SELECT MAX(id) FROM multi_volumes;", -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Selecting new multi volume ID number, SQLite result %d\n", status);
	id = sqlite3_column_int (db_row, 0);
	sqlite3_finalize (db_row);

	while (i < real_voleme_num)	{
		g_sprintf (sql_query, "UPDATE books SET multi_volume=%d WHERE id=%d;",
							id, multi_volume.books_ids [i]);
		sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf("\t\t<<< Updating table \'books\', SQLIte result: %d\n", status);
		sqlite3_finalize (db_row);
		
		++i;
	}
	
	set_statusbar_text (_("New multi volume book inserted!"));
}

/*
 *	Funkcja aktualizuje dane o ksiazce
 */

void	m_update_book	(void)	{
	gchar			sql_query	[3172];
	gint			status;
	gint			i;
	gint			real_voleme_num;
	sqlite3_stmt	*db_row;
	
	i = 0;
	real_voleme_num = multi_volume.volume_num;
		
	g_printf (">>> Updating data base ...\n");
	
	g_sprintf (sql_query, "UPDATE multi_volumes SET "
							"title=\'%s\', author=\'%d\', genere=\'%d\',"
							"publish_house=\'%d\', volume_num=\'%d\', description=\'%s\' "
							"WHERE "
							"id=%d;", 
							multi_volume.title, multi_volume.author, multi_volume.genere, 
							multi_volume.publish_house, multi_volume.volume_num,
							multi_volume.description, multi_volume.id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf("\t<<< Updating data in data base, SQLIte result: %d\n", status);
	sqlite3_finalize (db_row);
	
	g_sprintf (sql_query, "UPDATE books SET multi_volume=0 WHERE multi_volume=%d;", multi_volume.id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Setting \'multi_volume\' = 0, where \'multi_volume\' = %d, SQLite result %d\n", 
			  multi_volume.id, status);
	sqlite3_finalize (db_row);

	while (i < real_voleme_num)	{
		g_sprintf (sql_query, "UPDATE books SET multi_volume=%d WHERE id=%d;",
							multi_volume.id, multi_volume.books_ids [i]);
		sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
		status = sqlite3_step (db_row);
		g_printf("\t\t<<< Updating table \'books\', SQLIte result: %d\n", status);
		sqlite3_finalize (db_row);
		
		++i;
	}
	
	set_statusbar_text (_("Book informations updated!"));
}

/*
 *	Funkcja wczytuje dane wskazanej ksiazki do pol w 'main_win' i tworzy modele
 *	dla wszystkich widgetow 'GtkComboBox' wybierajha przy tym opce zapisana w 
 *	bazie danych
 */

void	m_display_book_data	(void)	{
	GtkTreeView		*treeview;
	GtkTreeModel	*store;
	GtkTreeIter 	iter;	
	GtkWidget		*tmp;
	GtkTextBuffer 	*text_buffer;
	gboolean		status;
	gchar			sql_query	[128];
	sqlite3_stmt	*db_row;
	
	tmp = glade_xml_get_widget (main_win_xml, "m_title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), multi_volume.title);

	tmp = glade_xml_get_widget (main_win_xml, "m_author_lb");
	g_sprintf (sql_query, "SELECT author FROM authors WHERE id=\'%d\';", multi_volume.author);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (main_win_xml, "m_genere_lb");
	g_sprintf (sql_query, "SELECT genere FROM generes WHERE id=\'%d\';", multi_volume.genere);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (main_win_xml, "m_pub_house_lb");
	g_sprintf (sql_query, "SELECT publish_house FROM publish_houses WHERE id=\'%d\';", 
							multi_volume.publish_house);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_label_set_text (GTK_LABEL (tmp), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (main_win_xml, "m_volume_num_lb");
	g_sprintf (sql_query, "%d", multi_volume.volume_num);
	gtk_label_set_text (GTK_LABEL (tmp), sql_query);
	
	treeview = (gpointer) glade_xml_get_widget (main_win_xml, "m_books_tview");
	store = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
	
	g_sprintf (sql_query, "SELECT id, title FROM books WHERE multi_volume=\'%d\';", multi_volume.id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	
	while (status == 100)	{
		gtk_list_store_append (GTK_LIST_STORE (store), &iter);
		gtk_list_store_set (GTK_LIST_STORE (store), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								-1);
		status = sqlite3_step (db_row);
	}
	
	sqlite3_finalize (db_row);
	
	/*
	if (book.lended == 0)	{
		tmp = glade_xml_get_widget (main_xml, "s_lend_book_togbut");
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp), FALSE);
	}
	else	{
		tmp = glade_xml_get_widget (main_xml, "s_lend_book_togbut");
		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (tmp), TRUE);
	}
	*/
	tmp = glade_xml_get_widget (main_win_xml, "m_description_tview");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, multi_volume.description, strlen (multi_volume.description));
	
	set_widget_sensinitive (main_win_xml, "m_remove_book_but", TRUE);
	set_widget_sensinitive (main_win_xml, "m_edit_book_but", TRUE);
}

/*
 *	Funkcja czysci pola w oknie 'main_win'
 */

void	m_clear_book_display (void)	{
	GtkWidget		*tmp;
	GtkTextBuffer 	*text_buffer;
	
	tmp = glade_xml_get_widget (main_win_xml, "m_title_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");

	tmp = glade_xml_get_widget (main_win_xml, "m_author_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "m_genere_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "m_pub_house_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "m_volume_num_lb");
	gtk_label_set_text (GTK_LABEL (tmp), "");
	
	tmp = glade_xml_get_widget (main_win_xml, "m_books_tview");
	clear_list_view (GTK_TREE_VIEW (tmp));
	
	tmp = glade_xml_get_widget (main_win_xml, "m_description_tview");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, "", strlen (""));
	
	set_widget_sensinitive (main_win_xml, "m_remove_book_but", FALSE);
	set_widget_sensinitive (main_win_xml, "m_edit_book_but", FALSE);
}

/*
 *	Funkcja usuwa ksiażke o ID wskazanym przez zmienna 'multi_volume.id'
 */

void	m_remove_book			(void)	{
	gchar			sql_query	[64];
	gint 			status;
	sqlite3_stmt	*db_row;
	
	g_sprintf (sql_query, "DELETE FROM multi_volumes WHERE id=\'%d\';", multi_volume.id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	g_printf ("<<< Deleting multi volume book, SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	
	g_sprintf (sql_query, "UPDATE books SET multi_volume=0 WHERE multi_volume=\'%d\';", multi_volume.id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	g_printf ("<<< Updating table \'books\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja wczytuje dane wskazanej ksiazki do okna edycji. 
 */

void			m_edit_book_data				(void)	{
	GtkTreeView		*treeview;
	GtkTreeModel	*store;
	GtkTreeIter 	iter;	
	GtkWidget		*tmp;
	GtkTextBuffer	*text_buffer;
	sqlite3_stmt	*db_row;
	gchar			sql_query	[64];
	gchar			string		[2];
	gint			status;
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_books_number_lb");
	g_sprintf (string, "%d", multi_volume.volume_num);
	gtk_label_set_text (GTK_LABEL (tmp), string);
	
	if (multi_volume.volume_num == 30)	{
		set_widget_sensinitive (multi_volume_xml, "m_add_book_but", FALSE);
	}
	
	treeview = (gpointer) glade_xml_get_widget (multi_volume_xml, "m_books_tview");
	store = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
	
	g_sprintf (sql_query, "SELECT id, title FROM books WHERE multi_volume=\'%d\';", multi_volume.id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	
	while (status == 100)	{
		gtk_list_store_append (GTK_LIST_STORE (store), &iter);
		gtk_list_store_set (GTK_LIST_STORE (store), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								-1);
		status = sqlite3_step (db_row);
	}
	
	sqlite3_finalize (db_row);
	
	g_printf (">>> Auto choosing books, setting \'tmp\' filed = 1, where \'multi_volume\' is %d\n", multi_volume.id);
	g_sprintf (sql_query, "UPDATE books SET tmp=1 WHERE multi_volume=\'%d\';", multi_volume.id);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_title_en");
	gtk_entry_set_text (GTK_ENTRY (tmp), multi_volume.title);

	tmp = glade_xml_get_widget (multi_volume_xml, "m_author_en");
	g_sprintf (sql_query, "SELECT author FROM authors WHERE id=\'%d\';", multi_volume.author);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (tmp)->child), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_genere_en");
	g_sprintf (sql_query, "SELECT genere FROM generes WHERE id=\'%d\';", multi_volume.genere);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (tmp)->child), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_pub_house_en");
	g_sprintf (sql_query, "SELECT publish_house FROM publish_houses WHERE id=\'%d\';", multi_volume.publish_house);
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	sqlite3_step (db_row);
	gtk_entry_set_text (GTK_ENTRY (GTK_BIN (tmp)->child), (gchar *) sqlite3_column_text (db_row, 0));
	sqlite3_finalize (db_row);
	
	tmp = glade_xml_get_widget (multi_volume_xml, "m_description_en");
	text_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (tmp));
	gtk_text_buffer_set_text (text_buffer, multi_volume.description, strlen (multi_volume.description));
}

/*
 *	Funkcja zeruje wszystkie zmienne w strukturze 'multi_volume'. Funkcja
 *	wywolywana jest po zakonczeniu pracy z dana ksiazka.
 */

void	m_reset_multi_volume_struc		(void)	{
	multi_volume.id = 0;
	g_sprintf (multi_volume.title, "");
	multi_volume.author = 0;
	multi_volume.genere = 0;
	multi_volume.publish_house = 0;
	g_sprintf (multi_volume.description, "");
	multi_volume.lended = 0;
}
