/***************************************************************************
 *            db-fun.c
 *
 *  Mon Aug 22 10:11:02 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomek@paradox.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <sqlite3.h>
#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <stdio.h>

#include "db-fun.h"
#include "support.h"
 
/*
 *	Funkcja wywolywana jest podczas pierwszego uruchomienia programu; tworzy
 *	niezbedne pliki i tabele w bazie danych oraz wstawia podstawowe dane (kilka
 *	gatunkow ksiazek).
 */
 
void	first_run							(void)	{
	sqlite3_stmt	*db_row;
	gint			status;
	gchar			command	[1024];
	gchar 			db_path	[1024];
	
	g_printf ("This is first run of GBiblioteka, program must create base files, please wait...\n");
	
	g_sprintf (command, "%s/.gbiblioteka", g_get_home_dir ());
	status = g_mkdir (command, 0711);
	
	g_sprintf (db_path, "%s/.gbiblioteka/database", g_get_home_dir ());
	status = sqlite3_open (db_path, &db_handler);
	g_printf ("<<< Opening data base, SQLite result: %d\n", status);

	status = sqlite3_prepare(db_handler, "CREATE TABLE books "
										 "(id INTEGER PRIMARY KEY AUTOINCREMENT,"
										 "multi_volume INTEGER,"
									 	 "title TEXT,"
										 "author INTEGER,"
										 "genere INTEGER,"
										 "publish_house INTEGER,"
										 "isbn INTEGER,"
										 "publish_year INTEGER,"
										 "pages INTEGER,"
										 "description TEXT,"
										 "lended INTEGER, "
										 "tmp INTEGER);",
										 -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("<<< Creating table \'books\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	
	status = sqlite3_prepare(db_handler, "CREATE TABLE multi_volumes "
										 "(id INTEGER PRIMARY KEY AUTOINCREMENT,"
										 "title TEXT,"
										 "author INTEGER,"
										 "genere INTEGER,"
										 "publish_house INTEGER,"
										 "volume_num INTEGER,"
										 "description TEXT,"
										 "lended INTEGER);", -1, &db_row, 0);								 
										 
	status = sqlite3_step (db_row);
	g_printf ("<<< Creating table \'multi_volumes\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	
	status = sqlite3_prepare(db_handler, "CREATE TABLE authors "
										 "(id INTEGER PRIMARY KEY AUTOINCREMENT,"
										 "author TEXT);", -1, &db_row, 0);								 
										 
	status = sqlite3_step (db_row);
	g_printf ("<<< Creating table \'authors\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	
	status = sqlite3_prepare(db_handler, "CREATE TABLE generes "
										 "(id INTEGER PRIMARY KEY AUTOINCREMENT,"
										 "genere TEXT);", -1, &db_row, 0);								 
										 
	status = sqlite3_step (db_row);
	g_printf ("<<< Creating table \'generes\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	
	status = sqlite3_prepare(db_handler, "CREATE TABLE publish_houses "
										 "(id INTEGER PRIMARY KEY AUTOINCREMENT,"
										 "publish_house TEXT);", -1, &db_row, 0);								 
										 
	status = sqlite3_step (db_row);
	g_printf ("<<< Creating table \'publishhousess\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	
	status = sqlite3_prepare(db_handler, "CREATE TABLE version "
										 "(dbversionmajor INTEGER, "
										 "dbversionminor INTEGER);", -1, &db_row, 0);
										 
	status = sqlite3_step (db_row);
	g_printf ("<<< Creating table \'version\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	
	g_printf (">>> Inserting base data into database...\n");
	/* TRANSLATORS Please translate only 'Other author' word !!! */
	status = sqlite3_prepare(db_handler, _("INSERT INTO authors (id, author) VALUES (NULL, \'Other author\');"), -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Table \'authors\', SQLite result: %d\n", status);
	
	/* TRANSLATORS Please translate only 'Other genere' word !!! */
	status = sqlite3_prepare(db_handler, _("INSERT INTO generes (id, genere) VALUES (NULL, \'Other genere\');"), -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Table \'generes\', SQLite result: %d\n", status);
	
	/* TRANSLATORS Please translate only 'Other publish house' word !!! */
	status = sqlite3_prepare(db_handler, _("INSERT INTO publish_houses (id, publish_house) VALUES (NULL, \'Other publish house\');"), -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Table \'publishhouses\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);

	status = sqlite3_prepare(db_handler, "INSERT INTO version (dbversionmajor, dbversionminor) VALUES (\'0\', \'8\');", -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Table \'version\', SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
	
	sqlite3_close (db_handler);
}

/*
 *	Funkcja sprawdza czy plik bazy danych istnieje
 */

gboolean	check_db_exist	(void)	{
	gchar		db_path	[1024];
	
	g_sprintf (db_path, "%s/.gbiblioteka/database", g_get_home_dir ());
	if (g_file_test (db_path, G_FILE_TEST_EXISTS))
		return TRUE;
	else
		return FALSE;
}

/*
 *	Funkcja otwiera polaczenie z baza danych
 */

void	open_db		(void)	{
	gchar	db_path	[1024];
	gint	status;
	
	g_sprintf (db_path, "%s/.gbiblioteka/database", g_get_home_dir ());
	
	status = sqlite3_open (db_path, &db_handler);
	g_printf ("Opening data base, SQLite result: %d\n", status);
}

/*
 *	Funkcja zamyka polaczenie z baza danych
 */

gboolean	close_db (void)	{
	gint	status;
	
	status = sqlite3_close (db_handler);
	
	g_printf ("Closing data base, SQLite result: %d\n", status);
	
	if (status ==! 0)
		return FALSE;
	else
		return TRUE;
}


/*
 *	Funkcja zwraca ilosc wierszy zwroconych przez wywolanie zapytania SQL
 *	podanego w argumencie 'swl_query'.
 *	Styl obslugiwanego zapytania: 'SELECT COUNT(zmienna) FROM tabela;'
 */

gint		count_returned_rows		(gchar	*sql_query)	{
	gint			status;
	gint			result;
	sqlite3_stmt	*db_row;
	
	g_printf ("\t<<< Counting returned rows...\n");
	
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Counting rows, SQLite result: %d\n", status);
	
	result = sqlite3_column_int (db_row, 0);
	
	sqlite3_finalize (db_row);
	
	return result;
}

/*
 *	Funkcja ustawia wartosc pol 'tmp' w bazie danych na 0
 */

void		clear_tmp_fields		(void)	{
	gint status;
	
	sqlite3_stmt	*db_row;
	sqlite3_prepare(db_handler, "UPDATE books SET tmp=0;", -1, &db_row, 0);
	status = sqlite3_step (db_row);
	g_printf ("<<< Cleaning \'tmp\' fields, SQLite result: %d\n", status);
	sqlite3_finalize (db_row);
}
