/***************************************************************************
 *            interface.c
 *
 *  Wed Aug 10 12:27:02 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomek@paradox.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <glade/glade.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <stdio.h>

#include "interface.h"
#include "support.h"
#include "lists-fun.h"
#include "other-callbacks.h"


#define DEVELOPMENT_GUI_FILE PACKAGE_DATA_DIR"/gbiblioteka/glade/gbiblioteka.glade"
//#define	DEVELOPMENT_GUI_FILE "/home/tomek/Projekty/Libglade-GBiblioteka/gbiblioteka.glade"

//#define DEVELOPMENT_ICON_FILE "/home/tomek/Projekty/Libglade-GBiblioteka/pixmaps/gbiblioteka.png"
#define DEVELOPMENT_ICON_FILE PACKAGE_DATA_DIR"/gbiblioteka/pixmaps/gbiblioteka.png"

/*
 *	Funkcja laduje plik XML z konfiguracja GUI sprawdza czy:
 *	- plik XML wygenerowany przez program Glade znajduje sie w katalogu
 *	  zdefiniowanym podczas instalacji
 *	- sprawdza obsluge 'gmodule' wymaganej do auto-podlaczenia sygnalow zwrotnych
 *	- sprawdza czy pliki graficzne programu znajduja sie na swoim miejscu
 *	  jezeli ich tam nie ma program zostanie uruchomiony i pokaze sie ostrzezenie
 */

gboolean	load_gui_xml			(void)	{
	GError		*error;
	
	error = NULL;
	
	main_win_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "main_win", NULL);
	icon = gdk_pixbuf_new_from_file (DEVELOPMENT_ICON_FILE, &error);
	
	if (main_win_xml == NULL)	{
		GtkWidget	*window;
		gint		status;
		
		window = gtk_message_dialog_new_with_markup	(NULL,
									GTK_DIALOG_MODAL,
									GTK_MESSAGE_ERROR,
									GTK_BUTTONS_CLOSE,
									_("<b><span size=\"large\">Critical error</span></b>"));
		
		gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (window),
									_("GBiblioteka can't load Glade XML file which contain GUI\n"
									"configuration. Please check if this file exist:"
									"<i>%s</i> ."),
									DEVELOPMENT_GUI_FILE);
		
		status = gtk_dialog_run (GTK_DIALOG (window));
		switch (status)	{
			case GTK_RESPONSE_CLOSE:
				gtk_widget_destroy (window);
				break;
			case GTK_RESPONSE_DELETE_EVENT:
				gtk_widget_destroy (window);
				break;
			default:
				gtk_widget_destroy (window);
		}
		
		return FALSE;
	}
	else if (g_module_supported () == FALSE)	{
		GtkWidget	*window;
		gint		status;
		
		window = gtk_message_dialog_new_with_markup	(NULL,
									GTK_DIALOG_MODAL,
									GTK_MESSAGE_ERROR,
									GTK_BUTTONS_CLOSE,
									_("<span size=\"large\"><b>Critical error</b></span>"));
		
		gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (window),
									_("GModule (GLib component) isn't supported by your operating\n"
									"system, for more informations see <i>http://www.gtk.org/</i>."));
		
		status = gtk_dialog_run (GTK_DIALOG (window));
		switch (status)	{
			case GTK_RESPONSE_CLOSE:
				gtk_widget_destroy (window);
				break;
			case GTK_RESPONSE_DELETE_EVENT:
				gtk_widget_destroy (window);
				break;
			default:
				gtk_widget_destroy (window);
		}
		
		return FALSE;
	}

	else if (icon == NULL)	{
		printf ("Failed to load pixbuf file: %s: %s\n",
               DEVELOPMENT_ICON_FILE, error->message);
		g_error_free (error);
		return TRUE;
	}
}

/*
 *	Funkcja sprawdza czy w danej zmiennej typu GladeXML znajduje sie jakas 
 *	wartosc czy jest on pusty. Kaqzde okno po zniszczeniu ustawia wartosc swojej
 *	zmiennej typu GladeXML na NULL. Jest to potrzebne, poniewaz jednoczesne
 *	uzywanie niektorych okien moze zawiesic dzialanie programu, lub uszkodzic
 *	baze danych.
 */

gboolean	check_if_dialog_exist		(GladeXML	*xml)	{
	if (xml == NULL)	{
		return FALSE;
	}
	else	{
		return TRUE;
	}
}

/*
 *	Funkcja tworzy okno 'main_win'
 */


GtkWidget	*create_main_win (void)	{
	GtkListStore 		*store;
    GtkCellRenderer 	*renderer;
    GtkTreeViewColumn 	*column;
	GtkWidget 			*widget;
	GtkWidget			*window;
	
	window = glade_xml_get_widget (main_win_xml, "main_win");
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	glade_xml_signal_autoconnect (main_win_xml);
	
	/*	Tworzymy liste 'single_volume_tview'	*/
	
	create_single_volume_view ();

	/*	Tworzymy liste 'multi_volume_tview'	*/
	
	create_multi_volume_view ();
	
	/*	Tworzymy liste 'm_books_tview'	*/
	
	create_m_books_view (0);
	
	set_widget_sensinitive (main_win_xml, "s_edit_book_but", FALSE);
	set_widget_sensinitive (main_win_xml, "s_remove_book_but", FALSE);
	set_widget_sensinitive (main_win_xml, "m_edit_book_but", FALSE);
	set_widget_sensinitive (main_win_xml, "m_remove_book_but", FALSE);
	
	return	window;
}

/*
 *	Funkcja tworzy okno 'multi_volume_dlg'
 *	Opcja 'mode' ustawia tytul na:
 *		- 0 - tytul okna dodawania
 *		- 1 - tytul okna edycji
 */

GtkWidget	*create_multi_volume_dlg			(gint	mode)	{
	GtkWidget	*window;
	GtkWidget	*widget;
	
	multi_volume_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "multi_volume_dlg", NULL);
	window = glade_xml_get_widget (multi_volume_xml, "multi_volume_dlg");	
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	glade_xml_signal_autoconnect (multi_volume_xml);
	
	switch (mode)	{
		case 0:
			gtk_window_set_title (GTK_WINDOW (window), _("Adding multi volume item"));
			widget = glade_xml_get_widget (multi_volume_xml, "m_volume_update_but");
			set_widget_sensinitive (multi_volume_xml, "m_remove_book_but", FALSE);
			gtk_widget_hide (widget);
			break;
		case 1:
			gtk_window_set_title (GTK_WINDOW (window), _("Editing multi volume item"));
			widget = glade_xml_get_widget (multi_volume_xml, "m_volume_save_but");
			set_widget_sensinitive (multi_volume_xml, "m_remove_book_but", FALSE);
			gtk_widget_hide (widget);
			break;
	}
	
	return window;
}

GtkWidget	*create_select_m_books_dlg			(void)	{
	GtkWidget	*window;
	
	select_m_books_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "select_m_books_dlg", NULL);
	window = glade_xml_get_widget (select_m_books_xml, "select_m_books_dlg");	
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	glade_xml_signal_autoconnect (select_m_books_xml);
	
	set_widget_sensinitive (select_m_books_xml, "select_m_books_add_but", FALSE);
	
	return window;
}

/*
 *	Funkcja tworzy okno 'single_book_dlg'
 *	Opcja 'mode' ustawia tytul na:
 *		- 0 - tytul okna dodawania
 *		- 1 - tytul okna edycji
 */

GtkWidget	*create_single_book_dlg	(gint	mode)	{
	GtkWidget	*window;
	GtkWidget	*widget;
	
	single_book_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "single_book_dlg", NULL);
	window = glade_xml_get_widget (single_book_xml, "single_book_dlg");
	gtk_window_set_icon (GTK_WINDOW (window), icon);	
	glade_xml_signal_autoconnect (single_book_xml);
	
	switch (mode)	{
		case 0:
			gtk_window_set_title (GTK_WINDOW (window), _("Adding book"));
			widget = glade_xml_get_widget (single_book_xml, "single_book_update_but");
			gtk_widget_hide (widget);
			break;
		case 1:
			gtk_window_set_title (GTK_WINDOW (window), _("Editing book"));
			widget = glade_xml_get_widget (single_book_xml, "single_book_save_but");
			gtk_widget_hide (widget);
			break;
	}
	
	return window;
}

GtkWidget	*create_about_dlg	(void)	{
	GtkWidget	*window;
	
	about_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "about_dlg", NULL);
	window = glade_xml_get_widget (about_xml, "about_dlg");	
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	
	gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (window), VERSION);
	
	gtk_about_dialog_set_logo (GTK_ABOUT_DIALOG (window), icon);
	
	return window;
}

GtkWidget	*create_settings_dlg	(void)	{
	GtkWidget	*window;
	
	settings_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "settings_dlg", NULL);
	window = glade_xml_get_widget (settings_xml, "settings_dlg");	
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	glade_xml_signal_autoconnect (settings_xml);
	
	return window;
}

/*
 *	Funkcja tworzy okno 'add_book_type_dlg' i tworzy odpowiednie okno dodawania
 *	ksiazki (pozycji jednotomowej lub wielotomowej). Uzylem dwoch
 *	niestandartowych numerow ID zwracanych przed przez przycisko, oto one:
 *		- przycisk "single_but" zwraca ID odpowiedzi = 98
 *		- przycisk "multi_but" zwraca ID odpowiedzi = 99
 *
 *	Funkcja zwraca wartosc liczbowa:
 *		- zwrocenie liczby 1 oznacza dodawanie pojedynczej ksiazki
 *		- zwrocenie liczby 2 oznacza dodawanie wielotomowej ksiazki
 */

gint		create_add_book_type_dlg			(void)	{
	GladeXML	*xml;
	GtkWidget	*window;
	gint		response_id;
	
	xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "add_book_type_dlg", NULL);
	window = glade_xml_get_widget (xml, "add_book_type_dlg");	
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	
	response_id = gtk_dialog_run (GTK_DIALOG (window));
	
	switch (response_id)	{
		case GTK_RESPONSE_DELETE_EVENT:
			gtk_widget_destroy (window);
			break;
		case GTK_RESPONSE_CANCEL:
			gtk_widget_destroy (window);
			break;
		case 98:
			gtk_widget_destroy (window);
			return	1;
			break;
		case 99:
			gtk_widget_destroy (window);
			return	2;
			break;
	}
	
	g_free (xml);
}

/*
 *	Funkcja tworzy okno 'men_db_dlg' ustawiajac tresc etykiet itp. na adekwatna
 *	do edytowanej tabeli bazy danych.
 */

GtkWidget	*create_menage_data_dlg	(gint	mode)	{
	GtkWidget	*window;
	GtkWidget	*tmp;
	
	switch (mode)	{
		case 0:
			menage_authors_data_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "menage_data_dlg", NULL);
			window = glade_xml_get_widget (menage_authors_data_xml, "menage_data_dlg");
	
			glade_xml_signal_connect_data (menage_authors_data_xml, "on_menage_data_remove_but_clicked",
								   G_CALLBACK (on_menage_data_remove_but_clicked),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_authors_data_xml, "on_menage_data_add_but_clicked",
								   G_CALLBACK (on_menage_data_add_but_clicked),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_authors_data_xml, "on_menage_data_close_but_clicked",
								   GTK_SIGNAL_FUNC (on_menage_data_close_but_clicked),
								   GINT_TO_POINTER (mode));	
			glade_xml_signal_connect_data (menage_authors_data_xml, "on_menage_data_en_changed",
								   GTK_SIGNAL_FUNC (on_menage_data_en_changed),
								   GINT_TO_POINTER (mode));	
			glade_xml_signal_connect_data (menage_authors_data_xml, "on_menage_data_tview_cursor_changed",
								   GTK_SIGNAL_FUNC (on_menage_data_tview_cursor_changed),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_authors_data_xml, "on_menage_data_dlg_delete_event",
								   GTK_SIGNAL_FUNC (on_menage_data_dlg_delete_event),
								   GINT_TO_POINTER (mode));
			break;
		case 1:
			menage_generes_data_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "menage_data_dlg", NULL);
			window = glade_xml_get_widget (menage_generes_data_xml, "menage_data_dlg");
	
			glade_xml_signal_connect_data (menage_generes_data_xml, "on_menage_data_remove_but_clicked",
								   G_CALLBACK (on_menage_data_remove_but_clicked),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_generes_data_xml, "on_menage_data_add_but_clicked",
								   G_CALLBACK (on_menage_data_add_but_clicked),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_generes_data_xml, "on_menage_data_close_but_clicked",
								   GTK_SIGNAL_FUNC (on_menage_data_close_but_clicked),
								   GINT_TO_POINTER (mode));	
			glade_xml_signal_connect_data (menage_generes_data_xml, "on_menage_data_en_changed",
								   GTK_SIGNAL_FUNC (on_menage_data_en_changed),
								   GINT_TO_POINTER (mode));	
			glade_xml_signal_connect_data (menage_generes_data_xml, "on_menage_data_tview_cursor_changed",
								   GTK_SIGNAL_FUNC (on_menage_data_tview_cursor_changed),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_generes_data_xml, "on_menage_data_dlg_delete_event",
								   GTK_SIGNAL_FUNC (on_menage_data_dlg_delete_event),
								   GINT_TO_POINTER (mode));
			break;
		case 2:
			menage_pub_houses_data_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "menage_data_dlg", NULL);
			window = glade_xml_get_widget (menage_pub_houses_data_xml, "menage_data_dlg");
	
			glade_xml_signal_connect_data (menage_pub_houses_data_xml, "on_menage_data_remove_but_clicked",
								   G_CALLBACK (on_menage_data_remove_but_clicked),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_pub_houses_data_xml, "on_menage_data_add_but_clicked",
								   G_CALLBACK (on_menage_data_add_but_clicked),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_pub_houses_data_xml, "on_menage_data_close_but_clicked",
								   GTK_SIGNAL_FUNC (on_menage_data_close_but_clicked),
								   GINT_TO_POINTER (mode));	
			glade_xml_signal_connect_data (menage_pub_houses_data_xml, "on_menage_data_en_changed",
								   GTK_SIGNAL_FUNC (on_menage_data_en_changed),
								   GINT_TO_POINTER (mode));	
			glade_xml_signal_connect_data (menage_pub_houses_data_xml, "on_menage_data_tview_cursor_changed",
								   GTK_SIGNAL_FUNC (on_menage_data_tview_cursor_changed),
								   GINT_TO_POINTER (mode));
			glade_xml_signal_connect_data (menage_pub_houses_data_xml, "on_menage_data_dlg_delete_event",
								   GTK_SIGNAL_FUNC (on_menage_data_dlg_delete_event),
								   GINT_TO_POINTER (mode));
			break;
	}
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	
	switch (mode)	{
		case 0:
			gtk_window_set_title (GTK_WINDOW (window), _("Menage authors"));
			break;
		case 1:
			gtk_window_set_title (GTK_WINDOW (window), _("Menage generes"));
			break;
		case 2:
			gtk_window_set_title (GTK_WINDOW (window), _("Menage publish houses"));
			break;
	}
	
	switch (mode)	{
		case 0:
			tmp = glade_xml_get_widget (menage_authors_data_xml, "menage_data_lb");
			break;
		case 1:
			tmp = glade_xml_get_widget (menage_generes_data_xml, "menage_data_lb");
			break;
		case 2:
			tmp = glade_xml_get_widget (menage_pub_houses_data_xml, "menage_data_lb");;
			break;
	}
		
	switch (mode)	{
		case 0:
			gtk_label_set_text (GTK_LABEL (tmp), _("Now you can menage your "
										  "author base by adding or removing them. "
										  "Only author \'Other author\' can't be "
										  "removed. \"He\" is default author in "
										  "GBiblioteka."));
			break;
		case 1:
			gtk_label_set_text (GTK_LABEL (tmp), _("Now you can menage your "
										  "generes base by adding or removing them. "
										  "Only author \'Other genere\' can't be "
										  "removed. It\'s default genere in "
										  "GBiblioteka."));
			break;
		case 2:
			gtk_label_set_text (GTK_LABEL (tmp), _("Now you can menage your "
										  "publish houses base by adding or removing them. "
										  "Only author \'Other publish house\' can't be "
										  "removed. It\'s default punlish house in "
										  "GBiblioteka."));
			break;
	}
	
	switch (mode)	{
		case 0:
			tmp = glade_xml_get_widget (menage_authors_data_xml, "men_db_entry_lb");
			break;
		case 1:
			tmp = glade_xml_get_widget (menage_generes_data_xml, "men_db_entry_lb");
			break;
		case 2:
			tmp = glade_xml_get_widget (menage_pub_houses_data_xml, "men_db_entry_lb");;
			break;
	}
	
	switch (mode)	{
		case 0:
			gtk_label_set_markup (GTK_LABEL (tmp), _("<b>First and last name of author</b>"));
			break;
		case 1:
			gtk_label_set_markup (GTK_LABEL (tmp), _("<b>Genere name</b>"));
			break;
		case 2:
			gtk_label_set_markup (GTK_LABEL (tmp), _("<b>Publish house name</b>"));
			break;
	}
	
	switch (mode)	{
		case 0:
			set_widget_sensinitive (menage_authors_data_xml, "menage_data_add_but", FALSE);
			set_widget_sensinitive (menage_authors_data_xml, "menage_data_remove_but", FALSE);
			break;
		case 1:
			set_widget_sensinitive (menage_generes_data_xml, "menage_data_add_but", FALSE);
			set_widget_sensinitive (menage_generes_data_xml, "menage_data_remove_but", FALSE);
			break;
		case 2:
			set_widget_sensinitive (menage_pub_houses_data_xml, "menage_data_add_but", FALSE);
			set_widget_sensinitive (menage_pub_houses_data_xml, "menage_data_remove_but", FALSE);
			break;
	}

	/*	Tworzymu odpowiednia liste 'menage_data_tview'	*/
	create_menage_data_view (mode);
	
	load_data (mode);
	
	return window;	
}

GtkWidget	*create_search_tool_dlg				(void)	{
	GtkWidget	*window;
	GtkWidget	*tmp;
	
	search_tool_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "search_tool_dlg", NULL);
	window = glade_xml_get_widget (search_tool_xml, "search_tool_dlg");	
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	glade_xml_signal_autoconnect (search_tool_xml);
	
	tmp = glade_xml_get_widget (search_tool_xml, "search_stop_but");
	gtk_widget_hide (tmp);
	
	create_search_tool_view ();
	
	return window;
}

GtkWidget	*create_display_book_info_dlg		(void)	{
	GtkWidget	*window;
	
	display_book_info_xml = glade_xml_new (DEVELOPMENT_GUI_FILE, "display_book_info_dlg", NULL);
	window = glade_xml_get_widget (display_book_info_xml, "display_book_info_dlg");	
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	glade_xml_signal_autoconnect (display_book_info_xml);
	
	return window;
}

/*
 *	Funkcja tworzy okno z ostrzezeniem, informacja, lub bledem.
 *	Wartosci zmiennej 'dlg_mode':
 *		0 - informacja
 *		1 - ostrzezeniem
 *		2 - blad
 */

void		show_message_dlg		(gchar		*first_text,
									 gchar		*sec_text,
									 gint		dlg_mode)
{
	GtkWidget	*window;
	GtkWidget	*main_window;
	gchar		string	[64];
	
	g_sprintf (string, "<span size=\"large\"><b>%s</b></span>", first_text);
	
	main_window = glade_xml_get_widget (main_win_xml, "main_win");
	
	switch (dlg_mode)	{
		case 0:
			window = gtk_message_dialog_new (GTK_WINDOW (main_window),
											 GTK_DIALOG_DESTROY_WITH_PARENT,
        	    	                         GTK_MESSAGE_INFO,
            	    	                     GTK_BUTTONS_OK,
											 NULL);
			gtk_window_set_icon (GTK_WINDOW (window), icon);
			gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (window), string);
			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (window), "%s", sec_text);
			gtk_dialog_run (GTK_DIALOG (window));
			gtk_widget_destroy (window);
			break;
		case 1:
			window = gtk_message_dialog_new (GTK_WINDOW (main_window),
											 GTK_DIALOG_DESTROY_WITH_PARENT,
        	    	                         GTK_MESSAGE_WARNING,
            	    	                     GTK_BUTTONS_CLOSE,
											 NULL);
			gtk_window_set_icon (GTK_WINDOW (window), icon);
			gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (window), string);
			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (window), "%s", sec_text);
			gtk_dialog_run (GTK_DIALOG (window));
			gtk_widget_destroy (window);
			break;
		case 2:
			window = gtk_message_dialog_new (GTK_WINDOW (main_window),
											 GTK_DIALOG_DESTROY_WITH_PARENT,
        	    	                         GTK_MESSAGE_ERROR,
            	    	                     GTK_BUTTONS_CLOSE,
											 NULL);
			gtk_window_set_icon (GTK_WINDOW (window), icon);
			gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (window), string);
			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (window), "%s", sec_text);
			gtk_dialog_run (GTK_DIALOG (window));
			gtk_widget_destroy (window);
			break;
		default:
			g_printf ("(ERROR) Bad value of \'dlg_mode\' passed to \'show_message_dlg ()\'\n");
		}
}

gboolean	show_question_dlg			(gchar		*first_text,
										 gchar		*sec_text)
{
	GtkWidget	*window;
	GtkWidget	*main_window;
	gint		response_id;
	gboolean	status;	
	gchar		string	[64];
	
	g_sprintf (string, "<span size=\"large\"><b>%s</b></span>", first_text);

	main_window = glade_xml_get_widget (main_win_xml, "main_win");

	window = gtk_message_dialog_new (GTK_WINDOW (main_window),
											 GTK_DIALOG_DESTROY_WITH_PARENT,
        	    	                         GTK_MESSAGE_QUESTION,
            	    	                     GTK_BUTTONS_YES_NO,
											 NULL);
	gtk_window_set_icon (GTK_WINDOW (window), icon);
	gtk_message_dialog_set_markup (GTK_MESSAGE_DIALOG (window), string);
	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (window), "%s", sec_text);
	response_id = gtk_dialog_run (GTK_DIALOG (window));
	
	switch (response_id)	{
		case GTK_RESPONSE_DELETE_EVENT:
			gtk_widget_destroy (window);
			status = FALSE;
			break;
		case GTK_RESPONSE_YES:
			gtk_widget_destroy (window);
			status = TRUE;
			break;
		case GTK_RESPONSE_NO:
			gtk_widget_destroy (window);
			status = FALSE;
			break;
	}
	
	return status;
}

void		set_statusbar_text	(gchar	*text)	{
	GtkWidget	*widget;
	gint		context_id;

	widget = glade_xml_get_widget (main_win_xml, "main_stat_bar");
	
	context_id = gtk_statusbar_get_context_id (GTK_STATUSBAR (widget), text);
	gtk_statusbar_push (GTK_STATUSBAR (widget), context_id, text);
}

/*
 *	Funkcja aktywuje/dezaktywuje widget
 *	Wartosci 'status':
 *		TRUE  - widget aktywny
 *		FALSE - widget nie aktywny
 */

void	set_widget_sensinitive (GladeXML	*xml,
								gchar		*widget_name,
								gboolean	status)	
{
	GtkWidget	*tmp;
	tmp = glade_xml_get_widget (xml, widget_name);
	
	gtk_widget_set_sensitive (tmp, status);
}
