/***************************************************************************
 *            main-callbacks.c
 *
 *  Wed Aug 10 12:41:37 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomek@paradox.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <stdio.h>

#include "main-callbacks.h"
#include "support.h"
#include "interface.h"
#include "db-fun.h"
#include "other_data-fun.h"
#include "book-fun.h"


gboolean
on_main_win_delete_event               (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
	close_db ();
	gtk_main_quit ();
	return FALSE;
}


void
on_add_book_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (menage_authors_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add new book while you\'re modifying authors base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add new book while you\'te modifying generes base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can'\t add new book while you\'re modifying publish houses base!"),
						  1);
	}
	else if (check_if_dialog_exist (single_book_xml) ||
			 check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add or mofify more than one book at the same time!"),
						  1);
	}
	else	{
		GtkWidget	*widget;
		gint		add_mode;
	
		add_mode = create_add_book_type_dlg ();
		switch (add_mode)	{
			case 1:
				widget = create_single_book_dlg (0);
				s_reset_book_stuc ();
				s_load_book_dlg_data ();
				gtk_widget_show (widget);
				break;
			case 2:
				widget = create_multi_volume_dlg (0);
				m_reset_multi_volume_struc ();
				m_load_book_dlg_data ();
				create_m_books_view (1);
				gtk_widget_show (widget);
				clear_tmp_fields ();
				m_clear_book_display ();
				break;
		}
	}
}


void
on_backup_data_activate                (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{

}


void
on_exit_activate                       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	close_db ();
	gtk_main_quit ();
}


void
on_edit_authors_activate               (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (single_book_xml) || 
		check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify authors base while you\'re adding or modifying book\'s informations!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_authors_data_xml))	{
		/* Nic nie robimy gdy okno juz istnieje	*/
	}
	else	{
		GtkWidget	*widget;
		widget = create_menage_data_dlg (0);
		gtk_widget_show (widget);
	}
}


void
on_edit_genere_base_activate           (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	
	if (check_if_dialog_exist (single_book_xml) || 
		check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify generes base while you\'re adding or modifying book\'s informations!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		/* Nic nie robimy gdy okno juz istnieje	*/
	}
	else	{
		GtkWidget	*widget;
		widget = create_menage_data_dlg (1);
		gtk_widget_show (widget);
	}
}


void
on_edit_pub_houses_base_activate       (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (single_book_xml) || 
		check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify publish houses base while you\'re adding or modifying book\'s informations!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		/* Nic nie robimy gdy okno juz istnieje	*/
	}
	else	{
		GtkWidget	*widget;
		widget = create_menage_data_dlg (2);
		gtk_widget_show (widget);
	}
}


void
on_search_activate                     (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (search_tool_xml))	{
		/* Nic nie robimy gdy okno juz istnieje	*/
	}
	else	{
		GtkWidget	*widget;
		
		widget = create_search_tool_dlg ();
		gtk_widget_show (widget);
	}
}


void
on_settings_activate                   (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (settings_xml))	{
		/* Nic nie robimy gdy okno juz istnieje	*/
	}
	else	{
		GtkWidget	*widget;
		widget = create_settings_dlg ();
		gtk_widget_show (widget);
	}
}


void
on_about_activate                      (GtkMenuItem     *menuitem,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (about_xml))	{
		/* Nic nie robimy gdy okno juz istnieje	*/
	}
	else	{
		GtkWidget	*widget;
		widget = create_about_dlg ();
		gtk_widget_show (widget);
	}
}


void
on_main_add_book_tbut_clicked          (GtkToolButton   *toolbutton,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (menage_authors_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add new book while you\'re modifying authors base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add new book while you\'re modifying generes base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can't add new book while you\'re modifying publish houses base!"),
						  1);
	}
	else if (check_if_dialog_exist (single_book_xml) ||
			 check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add or mofify more than one book at the same time!"),
						  1);
	}
	else	{
		GtkWidget	*widget;
		gint		add_mode;
	
		add_mode = create_add_book_type_dlg ();
		switch (add_mode)	{
			case 1:
				widget = create_single_book_dlg (0);
				s_reset_book_stuc ();
				s_load_book_dlg_data ();
				gtk_widget_show (widget);
				break;
			case 2:
				widget = create_multi_volume_dlg (0);
				m_reset_multi_volume_struc ();
				m_load_book_dlg_data ();
				create_m_books_view (1);
				gtk_widget_show (widget);
				clear_tmp_fields ();
				m_clear_book_display ();
				break;
		}
	}
}


void
on_main_exit_tbut_clicked              (GtkToolButton   *toolbutton,
                                        gpointer         user_data)
{
	close_db ();
	gtk_main_quit ();
}


void
on_main_search_en_activate             (GtkEntry        *entry,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (search_tool_xml))	{
		/* Nic nie robimy gdy okno juz istnieje	*/
	}
	else	{
		GtkWidget	*widget;
		GtkWidget	*search_entry;
		
		widget = create_search_tool_dlg ();
		
		search_entry = glade_xml_get_widget (search_tool_xml, "search_title_en");	
		gtk_entry_set_text (GTK_ENTRY (search_entry), gtk_entry_get_text (entry));
		
		gtk_widget_show (widget);
		
		on_search_run_but_clicked (NULL, NULL);
	}
}

void
on_main_search_tbut_clicked            (GtkToolButton   *toolbutton,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (search_tool_xml))	{
		/* Nic nie robimy gdy okno juz istnieje	*/
	}
	else	{
		GtkWidget	*widget;
		GtkWidget	*main_entry;
		GtkWidget	*search_entry;
		
		widget = create_search_tool_dlg ();
		
		main_entry = glade_xml_get_widget (main_win_xml, "main_search_en");
		search_entry = glade_xml_get_widget (search_tool_xml, "search_title_en");	
		gtk_entry_set_text (GTK_ENTRY (search_entry), gtk_entry_get_text (GTK_ENTRY (main_entry)));
		
		gtk_widget_show (widget);
		
		on_search_run_but_clicked (NULL, NULL);
	}
}

void
on_single_volume_tview_cursor_changed  (GtkTreeView     *treeview,
                                        gpointer         user_data)
{
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*widget;
	gint				book_id;
	
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	gtk_tree_selection_get_selected(selection, &model, &iter);
	
	gtk_tree_model_get (model, &iter, 0, &book_id, -1);
	
	widget = glade_xml_get_widget (main_win_xml, "main_ntbook");
	
	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 0);
	s_clear_book_display ();
	s_select_book_data (book_id);
	s_display_book_data ();
	//set_widget_sensinitive (dialog_xml, "menage_data_add_but", FALSE);
	//set_widget_sensinitive (dialog_xml, "menage_data_remove_but", TRUE);
}


void
on_multi_volume_tview_cursor_changed  (GtkTreeView     *treeview,
                                        gpointer         user_data)
{
	GtkTreeSelection	*selection;
	GtkTreeModel		*model;
  	GtkTreeIter			iter;
	GtkWidget			*widget;
	gint				book_id;
	
	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
	gtk_tree_selection_get_selected(selection, &model, &iter);
	
	gtk_tree_model_get (model, &iter, 0, &book_id, -1);
	
	widget = glade_xml_get_widget (main_win_xml, "main_ntbook");
	
	gtk_notebook_set_current_page (GTK_NOTEBOOK (widget), 1);
	m_clear_book_display ();
	m_select_book_data (book_id);
	m_display_book_data ();
	//set_widget_sensinitive (dialog_xml, "menage_data_add_but", FALSE);
	//set_widget_sensinitive (dialog_xml, "menage_data_remove_but", TRUE);
}

void
on_lend_book_togbut_clicked            (GtkButton       *button,
                                        gpointer         user_data)
{

}


void
on_s_edit_book_but_clicked               (GtkButton       *button,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (menage_authors_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book's informations while you\'re\nmodifying authors base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book's informations while you\'re\nmodifying generes base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book\'s informations while you\'re\nmodifying publish houses base!"),
						  1);
	}
	else if (check_if_dialog_exist (single_book_xml) ||
			 check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add or mofify more than one book at the same time!"),
						  1);
	}
	else	{
		GtkWidget	*widget;
		widget = create_single_book_dlg (1);
		s_load_book_dlg_data ();
		s_edit_book_data ();
		gtk_widget_show (widget);
	}
}


void
on_s_remove_book_but_clicked                (GtkButton       *button,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (menage_authors_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t remove book while you\'re modifying authors base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t remove book while you\'re modifying generes base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t remove book while you\'re modifying publish houses base!"),
						  1);
	}
	else if (check_if_dialog_exist (single_book_xml) ||
			 check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can't remove book from database while you're\nadding or modifying other book\'s informations!"),
						  1);
	}
	else	{
		gboolean	result;
	
		result = show_question_dlg (_("Do you really want to remove this book?"),
									_("Remember, that after this you wouldn't be "
									"able to restore this book informations.\n"
									"Do you want to continue?"));
	
		if (result == TRUE)	{
			GtkWidget	*widget;
			widget = glade_xml_get_widget (main_win_xml, "single_volume_tview");
	
			s_remove_book ();
			clear_list_view (widget);
			s_load_books_titles ();
			s_clear_book_display ();
			s_reset_book_stuc ();
		}
	}
}

void
on_multi_edit_book_but_clicked         (GtkButton       *button,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (menage_authors_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book's informations while you\'re\nmodifying authors base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book's informations while you\'re\nmodifying generes base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book\'s informations while you\'re\nmodifying publish houses base!"),
						  1);
	}
	else if (check_if_dialog_exist (single_book_xml) ||
			 check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add or mofify more than one book at the same time!"),
						  1);
	}
	else	{
		GtkWidget	*widget;
		widget = create_multi_volume_dlg (1);
		clear_tmp_fields ();
		create_m_books_view (1);
		m_load_book_dlg_data ();
		m_edit_book_data ();
		gtk_widget_show (widget);
		m_clear_book_display ();
	}
}


void
on_multi_remove_book_but_clicked       (GtkButton       *button,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (menage_authors_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t remove book while you\'re modifying authors base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t remove book while you\'re modifying generes base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t remove book while you\'re modifying publish houses base!"),
						  1);
	}
	else if (check_if_dialog_exist (single_book_xml) ||
			 check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can't remove book from database while you're\nadding or modifying other book\'s informations!"),
						  1);
	}
	else	{
		gboolean	result;
	
		result = show_question_dlg (_("Do you really want to remove this book?"),
									_("Remember, that after this you wouldn't be "
									"able to restore this book informations.\n"
									"Do you want to continue?"));
	
		if (result == TRUE)	{
			GtkWidget	*widget;
			widget = glade_xml_get_widget (main_win_xml, "multi_volume_tview");
	
			m_remove_book ();
			clear_list_view (widget);
			m_load_books_titles ();
			m_clear_book_display ();
			m_reset_multi_volume_struc ();
		}
	}
}

void
on_single_volume_tview_row_activated   (GtkTreeView     *treeview,
                                        GtkTreePath     *path,
                                        GtkTreeViewColumn *column,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (menage_authors_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book's informations while you\'re\nmodifying authors base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book's informations while you\'re\nmodifying generes base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book\'s informations while you\'re\nmodifying publish houses base!"),
						  1);
	}
	else if (check_if_dialog_exist (single_book_xml) ||
			 check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add or mofify more than one book at the same time!"),
						  1);
	}
	else	{
		GtkWidget	*widget;
		widget = create_single_book_dlg (1);
		s_load_book_dlg_data ();
		s_edit_book_data ();
		gtk_widget_show (widget);
	}
}


void
on_multi_volume_tview_row_activated    (GtkTreeView     *treeview,
                                        GtkTreePath     *path,
                                        GtkTreeViewColumn *column,
                                        gpointer         user_data)
{
	if (check_if_dialog_exist (menage_authors_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book's informations while you\'re\nmodifying authors base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_generes_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book's informations while you\'re\nmodifying generes base!"),
						  1);
	}
	else if (check_if_dialog_exist (menage_pub_houses_data_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t modify book\'s informations while you\'re\nmodifying publish houses base!"),
						  1);
	}
	else if (check_if_dialog_exist (single_book_xml) ||
			 check_if_dialog_exist (multi_volume_xml))	{
		show_message_dlg (_("Warning"),
						  _("You can\'t add or mofify more than one book at the same time!"),
						  1);
	}
	else	{
		GtkWidget	*widget;
		widget = create_multi_volume_dlg (1);
		clear_tmp_fields ();
		create_m_books_view (1);
		m_load_book_dlg_data ();
		m_edit_book_data ();
		gtk_widget_show (widget);
		m_clear_book_display ();
	}
}
