/***************************************************************************
 *            other_data-fun.c
 *
 *  Tue Sep  6 20:41:59 2005
 *  Copyright  2005  Tomek Jankowski
 *  Email	tomek@paradox.pl
 ****************************************************************************/

/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#include <glade/glade.h>
#include <gtk/gtk.h>
#include <glib.h>
#include <glib/gprintf.h>
#include <stdio.h>
#include <sqlite3.h>

#include "other_data-fun.h"
#include "interface.h"
#include "support.h"
#include "db-fun.h"

/*
 *	Funkcja laduje odpowiednie dane do listy 'menage_data_tview'
 */

void		load_data			(gint	mode)	{
	GtkTreeView			*treeview;
	GtkTreeModel		*store;
	GtkTreeIter 		iter;	
	gint				status;
	gint				rows;
	sqlite3_stmt		*db_row;
	
	status = 0;
	
	switch	(mode)	{
		case 0:
			treeview = GTK_TREE_VIEW (glade_xml_get_widget (menage_authors_data_xml, "menage_data_tview"));
			break;
		case 1:
			treeview = GTK_TREE_VIEW (glade_xml_get_widget (menage_generes_data_xml, "menage_data_tview"));
			break;
		case 2:
			treeview = GTK_TREE_VIEW (glade_xml_get_widget (menage_pub_houses_data_xml, "menage_data_tview"));
			break;
	}
	
	store = gtk_tree_view_get_model (GTK_TREE_VIEW (treeview));
	
	switch (mode)	{
		case 0:
			rows = count_returned_rows ("SELECT COUNT(id) FROM authors;");
			break;
		case 1:
			rows = count_returned_rows ("SELECT COUNT(id) FROM generes;");
			break;
		case 2:
			rows = count_returned_rows ("SELECT COUNT(id) FROM publish_houses;");
			break;
	}
	g_printf(">>> Loading data, number of returned rows: %d\n", rows);
	
	switch (mode)	{
		case 0: 
			sqlite3_prepare (db_handler, "SELECT id, author FROM authors;", -1, &db_row, 0);
			break;
		case 1:
			sqlite3_prepare (db_handler, "SELECT id, genere FROM generes;", -1, &db_row, 0);	
			break;
		case 2:
			sqlite3_prepare (db_handler, "SELECT id, publish_house FROM publish_houses;", -1, &db_row, 0);
			break;
	}
		
	status = sqlite3_step (db_row);
	g_printf ("\t<<< Got first row, SQLite result: %d\n", status);
	if (rows > 0)	{
		while (status == 100)		{
			gtk_list_store_append (GTK_LIST_STORE (store), &iter);
			gtk_list_store_set (GTK_LIST_STORE (store), &iter,
								0, sqlite3_column_int (db_row, 0), 
								1, sqlite3_column_text (db_row, 1),
								-1);
			status = sqlite3_step (db_row);
		}
		g_printf ("\t<<< Got last row, SQLite result: %d\n", status);
	}
	
	sqlite3_finalize (db_row);
}


/*
 *	Funkcja dodaje pozycje do bazy danych
 *
 *	UWAGA!
 *	Argument 'widget' musi wswkazywac na konkretny widget 'GtkEntry'
 */

void		add_item_to_database	(GtkWidget	*widget,
									 gint		mode)
{
	sqlite3_stmt	*db_row;
	gchar			sql_query[128];
	gint			status;

	switch (mode)	{
		case 0:
			g_sprintf (sql_query, "INSERT INTO authors (id, author) VALUES (NULL, \'%s\');",
								  gtk_entry_get_text (GTK_ENTRY (widget)));
			break;
		case 1:
			g_sprintf (sql_query, "INSERT INTO generes (id, genere) VALUES (NULL, \'%s\');",
								  gtk_entry_get_text (GTK_ENTRY (widget)));
			break;
		case 2:
			g_sprintf (sql_query, "INSERT INTO publish_houses (id, publish_house) VALUES (NULL, \'%s\');",
								  gtk_entry_get_text (GTK_ENTRY (widget)));
			break;
	}
	sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);	
	status = sqlite3_step (db_row);
	switch (mode)	{
		case 0:
			g_printf ("<<< Adding new author, SQLite result: %d\n", status);
			break;
		case 1:
			g_printf ("<<< Adding new genere, SQLite result: %d\n", status);
			break;
		case 2:
			g_printf ("<<< Adding new publish house, SQLite result: %d\n", status);
			break;
	}
	sqlite3_finalize (db_row);
}

/*
 *	Funkcja sprawdza czy usuwana pozycja jest wykorzystywana przez jakas ksiazke
 *	w bazie danych. Jezeli jest to liczy ilosc ksiazek wykorzystujacych dana 
 *	pozycje i uruchamia funkcje usuwaia.
 */

void		check_if_item_is_used	(gint		mode,
									 gint		id)
{
	if (id == 1)	{
		show_message_dlg (_("Can't remove item"),
						  _("This item is protected and it can't be removed!"),
						  1);
	}
	else	{
		gint			rows;
		gchar			string	[1024];
		
		switch (mode)	{
			case 0:
				g_printf (">>> Removing author from database...\n");
				g_sprintf (string,"SELECT COUNT(id) FROM books WHERE author=%d;", id);
				rows = count_returned_rows (string);
				g_sprintf (string,"SELECT COUNT(id) FROM multi_volumes WHERE author=%d;", id);
				rows = rows + count_returned_rows (string);
				g_printf ("\t<<< Item is used by %d book(s)\n", rows);
				break;
			case 1:
				g_printf (">>> Removing generer from database...\n");
				g_sprintf (string, "SELECT COUNT(id) FROM books WHERE genere=%d;", id);			
				rows = count_returned_rows (string);
				g_sprintf (string,"SELECT COUNT(id) FROM multi_volumes WHERE genere=%d;", id);
				rows = rows + count_returned_rows (string);
				g_printf ("\t<<< Item is used by %d book(s)\n", rows);
				break;
			case 2:
				g_printf (">>> Removing publish house from database...\n");
				g_sprintf (string,"SELECT COUNT(id) FROM books WHERE publish_house=%d;", id);
				rows = count_returned_rows (string);
				g_sprintf (string,"SELECT COUNT(id) FROM multi_volumes WHERE publish_house=%d;", id);
				rows = rows + count_returned_rows (string);
				g_printf ("\t<<< Item is used by %d book(s)\n", rows);
				break;
		}
		
		remove_data (mode, rows, id);
	}
}

/*
 *	Funkcja usuwa pozycje o 'id' wskazanym w argumencie rozrozniajac tabele
 *	po argumencie 'mode'. Jezleli argument 'rows' jest wiekszy niz 0 funkcja
 *	ostzega uzytkownika o tym, ze usuwana pozycja jest wykorzystana przez 
 *	jakas/jakies ksiazki w bazie danych. Jezeli user zgodzi sie na usuniecie
 *	usuwana pozycja we wszystkich ksiazakach wykorzystujacych ja zostanie 
 *	ustawiona na domyslna wartosc, czyli 1. 
 */

void		remove_data				(gint		mode,
									 gint		rows,
									 gint		id)
{
	gboolean		result;
	gint			status;
	sqlite3_stmt	*db_row;
	gchar			string		[1024];
	gchar			sql_query	[1024];
	
	if (rows > 0)	{			
		switch (mode)	{
			case 0:
				g_sprintf (string,
				_("You marked %d books as book(s) "
				"wrote by author you are removing at the moment. "
				"Author in all this books would be changed on "
				"\"Other author\" Are "
				"You sure You want to continue?"),
				rows);			
				result = show_question_dlg (_("Error while removing genere"), string);
			
				if (result == TRUE)	{
					g_sprintf (string, "DELETE FROM authors WHERE id=\'%d\';", id);
					sqlite3_prepare(db_handler, string, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf (">>> Removing author, SQLite result: %d\n", status);
					sqlite3_finalize (db_row);
				
					g_sprintf (string, "UPDATE books SET author=1 WHERE author=%d;", id);
					sqlite3_prepare(db_handler, string, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf ("\t>>> Updating table \'books\', result: %d\n", status);
					sqlite3_finalize (db_row);
					
					g_sprintf (string, "UPDATE multi_volumes SET author=1 WHERE author=%d;", id);
					sqlite3_prepare(db_handler, string, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf ("\t>>> Updating table \'multi_volumes\', result: %d\n", status);
					sqlite3_finalize (db_row);
				}
				break;
			case 1:
				g_sprintf (string, 
				_("You marked %d book(s) as book(s) "
				"in genere you are removing at the moment. "
				"Genere in all this books would be changed on "
				"\"Other genere\" Are "
				"You sure You want to continue?"),
				rows);
				result = show_question_dlg (_("Error while removing autor"), string);	
				if (result == TRUE)	{
					g_sprintf (sql_query, "DELETE FROM generes WHERE id=\'%d\';", id);
					sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf (">>> Removing genere, SQLite result: %d\n", status);
					sqlite3_finalize (db_row);
				
					g_sprintf (sql_query, "UPDATE books SET genere=1 WHERE genere=%d;", id);
					sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf ("\t>>> Updating table \'books\', result: %d\n", status);
					sqlite3_finalize (db_row);
					
					g_sprintf (sql_query, "UPDATE multi_volumes SET genere=1 WHERE genere=%d;", id);
					sqlite3_prepare(db_handler, sql_query, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf ("\t>>> Updating table \'multi_volumes\', result: %d\n", status);
					sqlite3_finalize (db_row);
				}
				break;
			case 2:
				g_sprintf (string,
				_("You marked %d book(s) as book(s) "
				"published by publishing house you are removing at the moment. "
				"Publish house in all this books would be changed on "
				"\"Other publish house\" Are "
				"You sure You want to continue?"),
				rows);
				result = show_question_dlg (_("Error while removing publish house"), 
				string);
				if (result == TRUE)	{
					g_sprintf (string, "DELETE FROM publish_houses WHERE id=%d;", id);
					sqlite3_prepare(db_handler, string, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf (">>> Removing publish houses, SQLite result: %d\n", status);
					sqlite3_finalize (db_row);
				
					g_sprintf (string, "UPDATE books SET publish_house=1 WHERE publish_house=%d;", id);
					sqlite3_prepare(db_handler, string, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf ("\t>>> Updating table \'books\', result: %d\n", status);
					sqlite3_finalize (db_row);
					
					g_sprintf (string, "UPDATE multi_volumes SET publish_house=1 WHERE publish_house=%d;", id);
					sqlite3_prepare(db_handler, string, -1, &db_row, 0);
					status = sqlite3_step (db_row);
					g_printf ("\t>>> Updating table \'multi_volumes\', result: %d\n", status);
					sqlite3_finalize (db_row);
				}
				break;
		}
	}
	else	{
		switch (mode)	{
			case 0:
				g_sprintf (string, "DELETE FROM authors WHERE id=%d;", id);
				sqlite3_prepare(db_handler, string, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Removing author, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			
				break;
			case 1:
				g_sprintf (string, "DELETE FROM generes WHERE id=%d;", id);
				sqlite3_prepare(db_handler, string, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Removing genere, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			
				break;
			case 2:
				g_sprintf (string, "DELETE FROM publish_houses WHERE id=%d;", id);
				sqlite3_prepare(db_handler, string, -1, &db_row, 0);
				status = sqlite3_step (db_row);
				g_printf (">>> Removing publish houses, SQLite result: %d\n", status);
				sqlite3_finalize (db_row);
			
				break;
		}
	}		
}
